import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Ophthalmologist related titles

ophthalmologist_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bOphthalmologist\b",
    r"(?i)\bOphthalmology\s?Specialist\b",
    r"(?i)\bEye\s?Specialist\b",
    r"(?i)\bEye\s?Doctor\b",
    r"(?i)\bOphthalmic\s?Surgeon\b",
    r"(?i)\bOphthalmology\b",

    # Misspellings & Typographical Errors
    r"(?i)\bOpthalmologist\b",
    r"(?i)\bOphtalmologist\b",
    r"(?i)\bOphthomologist\b",
    r"(?i)\bOphthalmologis\b",
    r"(?i)\bOpthomoligist\b",
    r"(?i)\bOphthalmalogist\b",
    r"(?i)\bOphthalmoloist\b",

    # Case Variations
    r"(?i)\bophthalmologist\b",
    r"(?i)\bOphthalmologist\b",
    r"(?i)\bOPHTHALMOLOGIST\b",
    r"(?i)\bOphthaLmologist\b",

    # Spanish Variants
    r"(?i)\bOftalmólogo\b",
    r"(?i)\bMédico\s?Oftalmólogo\b",
    r"(?i)\bEspecialista\s?en\s?Oftalmología\b",
    r"(?i)\bOftalmólogo\s?Médico\b",
    r"(?i)\bOftalmólogo\s?Quirúrgico\b",
    r"(?i)\bOftalmólogo\s?Pediátrico\b",
    r"(?i)\bOftalmólogo\s?Clínico\b",

    # Other Possible Variations (Including Doctor forms, Specialist forms)
    r"(?i)\bEye\s?Doctor\b",
    r"(?i)\bOphthalmic\s?Physician\b",
    r"(?i)\bOphthalmic\s?Specialist\b",
    r"(?i)\bOptometrist\b",  # Can be confused with Ophthalmologists in some regions
    r"(?i)\bVision\s?Specialist\b",
    r"(?i)\bOfthalmology\b",
    r"(?i)\bOphthalmogist\b",
    r"(?i)\bOphthalmolohist\b",
    r"(?i)\bOftalmologia\b",
]

# Exact matches that should be updated
ophthalmologist_exact_matches = {
    "Ophthalmologist",
    "Ophthalmology Specialist",
    "Eye Specialist",
    "Eye Doctor",
    "Ophthalmic Surgeon",
    "Opthalmologist",
    "Ophtalmologist",
    "Ophthomologist",
    "Ophthalmologis",
    "Opthomoligist",
    "Ophthalmalogist",
    "Ophthalmoloist",
    "Oftalmólogo",
    "Médico Oftalmólogo",
    "Especialista en Oftalmología",
    "Oftalmólogo Médico",
    "Oftalmólogo Quirúrgico",
    "Oftalmólogo Pediátrico",
    "Oftalmólogo Clínico",
    "Ophthalmic Physician",
    "Ophthalmic Specialist",
    "Optometrist",
    "Vision Specialist",
    'Ophtalmo',
}

# # Define patterns (these should NOT be changed)
# ophthalmologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

ophthalmologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Ophthalmology Resident',
    'Doctor Resident Of Ophthalmology',
}

# Create a mask for Ophthalmologist
mask_ophthalmologist = df['speciality'].str.contains('|'.join(ophthalmologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(ophthalmologist_exact_matches)

# mask_ophthalmologist_exclusions = df['speciality'].str.contains(ophthalmologist_exclusions, case=False, na=False, regex=True)
mask_ophthalmologist_exclusions = df['speciality'].isin(ophthalmologist_exclusions)

# Final mask: Select Ophthalmologist
mask_ophthalmologist_final = mask_ophthalmologist & ~mask_ophthalmologist_exclusions

# Store the original values that will be replaced
original_ophthalmologist_values = df.loc[mask_ophthalmologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_ophthalmologist_final, 'speciality'] = 'Ophthalmologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Ophthalmologist", 'green'))
print(df.loc[mask_ophthalmologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_ophthalmologist_values = df.loc[mask_ophthalmologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Ophthalmologist", "cyan"))
for original_ophthalmologist_value in original_ophthalmologist_values:
    print(f"✅ {original_ophthalmologist_value} → Ophthalmologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Ophthalmologist:", 'red'))
print(grouped_ophthalmologist_values)

# Print summary
matched_count_ophthalmologist = mask_ophthalmologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Ophthalmologist: "
        f"{matched_count_ophthalmologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Endocrinologist related titles

endocrinologist_variants = [
    r"(?i)\bendocrinologist\b",
    r"(?i)\bendocrinologists\b",
    r"(?i)\bendocrinologist\s?doctor\b",
    r"(?i)\bendocrinology\s?specialist\b",
    r"(?i)\bendocrinologist\s?specialist\b",
    r"(?i)\bboard\s?certified\s?endocrinologist\b",
    r"(?i)\bdoctor\s?of\s?endocrinology\b",
    r"(?i)\bdoctor\s?endocrinologist\b",
    r"(?i)\bendocrinologist\s?physician\b",
    r"(?i)\bendocrinologist\s?md\b",
    r"(?i)\bendocrinologist\s?mds\b",
    r"(?i)\bendocrinologist\s?consultant\b",
    r"(?i)\bendocrinologist\s?expert\b",
    r"(?i)\bendocrinologist\s?doctor\b",
    r"(?i)\bendocrinologist\s?physician\s?specialist\b",
    # Spanish variants
    r"(?i)\bendocrinólogo\b",
    r"(?i)\bendocrinóloga\b",
    r"(?i)\bendocrinólogos\b",
    r"(?i)\bendocrinólogas\b",
    r"(?i)\bespecialista\s?en\s?endocrinología\b",
    r"(?i)\bdoctor\s?en\s?endocrinología\b",
    # Misspellings
    r"(?i)\bendocrinolgist\b",
    r"(?i)\bendocrinologiest\b",
    r"(?i)\bendocrinlogist\b",
    r"(?i)\bendocrinologist\s?doctor\b",
    r"(?i)\bendocrinogist\b",
    r"(?i)\bendoocrinologist\b",
    r"(?i)\bendocrinolgist\b",
    r"(?i)\bendocrinologist\s?md\b",
    # Case-related errors
    r"(?i)\bendocrinologist\b",
    r"(?i)\bENDOCRINOLOGIST\b",
    r"(?i)\bEndocrinologist\b",
    r"(?i)\bendocrinologist\b",
    # Other Possible Variations
    r"(?i)\bboard\s?certified\s?endocrinologist\b",
    r"(?i)\bendocrinology\s?expert\b",
    r"(?i)\bendocrinologist\s?specialist\b",
    r"(?i)\bendocrinology\s?doctor\b",
    r"(?i)\bendocrinologist\s?consultant\b",
    r"(?i)\bendocrinology\s?practitioner\b",
    r"(?i)\bendocrinologist\s?physician\b",
    r"(?i)\bendocrine\s?specialist\b",
    r"(?i)\bendocrinologist\s?expert\b",
    r"(?i)\bMedico Endocrinologista\b",
    r"(?i)Endocrinologista",
    r"(?i)Endocrinoligista",
    r"(?i)\bHrt Pellet Therapy\b",
    r"(?i)\bEndocrino\b",
    r"(?i)\bHormone Optimization Coordinator\b",
]

# Exact matches that should be updated
endocrinologist_exact_matches = {
    "Endocrinologist",
    "Endocrinologists",
    "Endocrinologist Doctor",
    "Endocrinology Specialist",
    "Endocrinologist Specialist",
    "Board Certified Endocrinologist",
    "Doctor of Endocrinology",
    "Doctor Endocrinologist",
    "Endocrinologist Physician",
    "Endocrinologist MD",
    "Endocrinologist MDs",
    "Endocrinologist Consultant",
    "Endocrinologist Expert",
    "Endocrinologist Physician Specialist",
    "Endocrinólogo",
    "Endocrinóloga",
    "Endocrinólogos",
    "Endocrinólogas",
    "Especialista en Endocrinología",
    "Doctor en Endocrinología",
    "Endocrinolgist",
    "Endocrinologiest",
    "Endocrinlogist",
    "Endocrinogist",
    "Endoocrinologist",
    "ENDOCRINOLOGIST",
    "endocrinologist",
    "Endocrinology Expert",
    "Endocrinology Doctor",
    "Endocrinology Practitioner",
    "Endocrine Specialist",
    'Director Obesity Chair',
}

# Define patterns (these should NOT be changed)
endocrinologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Endocrinologist
mask_endocrinologist = df['speciality'].str.contains('|'.join(endocrinologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(endocrinologist_exact_matches)
mask_endocrinologist_exclusions = df['speciality'].isin(endocrinologist_exclusions)

# Final mask: Select Endocrinologist
mask_endocrinologist_final = mask_endocrinologist & ~mask_endocrinologist_exclusions

# Store the original values that will be replaced
original_endocrinologist_values = df.loc[mask_endocrinologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_endocrinologist_final, 'speciality'] = 'Endocrinologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Endocrinologist", 'green'))
print(df.loc[mask_endocrinologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_endocrinologist_values = df.loc[mask_endocrinologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Endocrinologist", "cyan"))
for original_endocrinologist_value in original_endocrinologist_values:
    print(f"✅ {original_endocrinologist_value} → Endocrinologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Endocrinologist:", 'red'))
print(grouped_endocrinologist_values)

# Print summary
matched_count_endocrinologist = mask_endocrinologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Endocrinologist: "
        f"{matched_count_endocrinologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Physician Assistant related titles

PA_variants = [
    # Standard Titles & Variants
    r"(?i)\bPhysician Assistant\b",
    r"(?i)\bPhysician's Assistant\b",
    r"(?i)\bPhysician Assistant Specialist\b",
    r"(?i)\bPA\b",
    r"(?i)\bPhysician's Associate\b",
    r"(?i)\bMedical Assistant\b",  # Depending on context, could refer to the same
    r"(?i)\bPhysician Assistant Professional\b",
    r"(?i)\bP A/P A -C\b",
    r"(?i)\bP AP A -C\b",
    r"(?i)\bAsistente Medico Estetico\b",
    r"(?i)\bAssistante Medecine Esthetique\b",
    r"(?i)\bAuxiliar Medicina Estetica\b",
    r"(?i)\bGeneral Koordinator\b",
    r"(?i)\bMd Assistant\b",
    r"(?i)\bAssiant\b",
    r"(?i)\bAsistent\b",
    r"(?i)\bAssistante Medicale\b",
    r"(?i)\bAsistente\b",
    r"(?i)\bAssistante\b",
    r"(?i)\bPhysician Associate\b",
    r"(?i)\bOperation Associate\b",
    r"(?i)\bPersonal Assistant To Dr\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPhyscian Assistant\b",
    r"(?i)\bPhysician Assitant\b",
    r"(?i)\bPhysician Asistant\b",
    r"(?i)\bPhysican Assistant\b",

    # Case Variations
    r"(?i)\bphysician assistant\b",
    r"(?i)\bPHYSICIAN ASSISTANT\b",
    r"(?i)\bPhYsIcIaN AsSiStAnT\b",
    r"(?i)\bPhysician AssistanT\b",

    # Spanish Variants
    r"(?i)\bAsistente Médico\b",
    r"(?i)\bAsistente de Médico\b",
    r"(?i)\bAsistente de Medicina\b",
    r"(?i)\bAsociado Médico\b",
    r"(?i)\bAsistente de Médico Profesional\b",

    # Other Possible Variations
    r"(?i)\bMedical Physician Assistant\b",
    r"(?i)\bHealth Practitioner Assistant\b",
    r"(?i)\bClinical Physician Assistant\b",
    r"(?i)\bPhysician's Healthcare Assistant\b",
    r"(?i)\bCoordinator Tsfp\b",
    r"(?i)\bPlastic Surgery Medical Assistant\b",
    r"(?i)\bPlastic Surgery Pa\b",
    r"(?i)\bAssistante Medecine Esthetique\b",
    r"(?i)\bPhysician Assistant\b",
    r"(?i)\bP AP A -C\b",
    r"(?i)\bPhysician Associate\b",
    r"(?i)\bAssistant Camera Operator\b",
    r"(?i)\bPersonal Assistant\b",
    r"(?i)\bPa\b",
    r"(?i)\bAssiant\b",
    r"(?i)\bPa-C\b",
    r"(?i)\bMd Assistant\b",
    r"(?i)\bAsistent\b",
    r"(?i)\bPlastic Surgery Medical Assistant\b",
    r"(?i)\bCertified Medical Assistant\b",
    r"(?i)\bAssistante Medecine Esthetique\b",
    r"(?i)\bAssistante Medicale\b",
    r"(?i)\bDoctor Asistent\b",
    r"(?i)\bMedical Assistant\b",
    r"(?i)\bMedical Care Assistant\b",
    r"(?i)\bMedicalScientific Assistant\b",
    r"(?i)\bMpas Pa-C\b",
    r"(?i)\bExeccutive Assistant\b",
    r"(?i)\bOperation Associate\b",
    r"(?i)\bPa C\b",
    r"(?i)\bGeneral Koordinator\b",
    r"(?i)\bSurgical Assistant\b",
    r"(?i)\bPlastic Surgery Pa\b",
    r"(?i)\bAsistente Medico Estetico\b",
    r"(?i)\bRn Pa\b",
    r"(?i)\bAesthetic Pa\b",
    r"(?i)\bAesthetic Dermatology Pa\b",
    r"(?i)\bCoordinator Tsfp\b",
    r"(?i)\bImd-Pa\b",
    r"(?i)\bAssistant Planner\b",
    r"(?i)\bAsistente De Gerencia\b",
    r"(?i)\bPersonal Assistant To Dr\b",
    r"(?i)\bAssistant Bu\b",
    r"(?i)\bNpd Assistant\b",
    r"(?i)\bAssistant To The Management\b",
    r"(?i)\bPolar & Care Assistant\b",
    r"(?i)\bPhysician Assistant Injector\b",
    r"(?i)\bSpecial Assistant\b",
    r"(?i)\bResearch Assistant\b",
    r"(?i)\bAssistant Practitioner\b",
]

# Exact matches that should be updated
PA_exact_matches = {
    "Physician Assistant",
    "Physician's Assistant",
    "Physician Assistant Specialist",
    "PA",
    "Physician's Associate",
    "Medical Assistant",
    "Physician Assistant Professional",
    "Physcian Assistant",
    "Physician Assitant",
    "Physician Asistant",
    "Physican Assistant",
    "Asistente Médico",
    "Asistente de Médico",
    "Asistente de Medicina",
    "Asociado Médico",
    "Asistente de Médico Profesional",
    "Medical Physician Assistant",
    "Health Practitioner Assistant",
    "Clinical Physician Assistant",
    "Physician's Healthcare Assistant",
    "P AP A -C",
    'Assistant',
    'assistant',
    'Physician AssistantFounder',
    'Physician AssistantOwner',
    'Physicians Assitant',
    'Physician Coordinator',
    'Orthopedic Physician S Assistant',
    'DMS PAC CAC',
}

# # Define patterns (these should NOT be changed)
# PA_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

PA_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Physician Assistant
mask_PA = df['speciality'].str.contains('|'.join(PA_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(PA_exact_matches)

# mask_PA_exclusions = df['speciality'].str.contains(PA_exclusions, case=False, na=False, regex=True)
mask_PA_exclusions = df['speciality'].isin(PA_exclusions)

# Final mask: Select Physician Assistant
mask_PA_final = mask_PA & ~mask_PA_exclusions

# Store the original values that will be replaced
original_PA_values = df.loc[mask_PA_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_PA_final, 'speciality'] = 'Physician Assistant'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Physician Assistant", 'green'))
print(df.loc[mask_PA_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_PA_values = df.loc[mask_PA_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Physician Assistant", "cyan"))
for original_PA_value in original_PA_values:
    print(f"✅ {original_PA_value} → Physician Assistant")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Physician Assistant:", 'red'))
print(grouped_PA_values)

# Print summary
matched_count_PA = mask_PA_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Physician Assistant: "
        f"{matched_count_PA}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Medical Spa Manager related titles

spa_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bMedical\s?Spa\s?Manager\b",
    r"(?i)\bMed\s?Spa\s?Manager\b",
    r"(?i)\bSpa\s?Medical\s?Manager\b",
    r"(?i)\bMedical\s?Aesthetic\s?Spa\s?Manager\b",
    r"(?i)\bManager\s?of\s?Medical\s?Spa\b",
    r"(?i)\bDirector\s?of\s?Medical\s?Spa\b",
    r"(?i)\bMedical\s?Wellness\s?Spa\s?Manager\b",
    r"(?i)\bSpa\s?Manager\s?\(Medical\)\b",
    r"(?i)\bSpa Manager\b",
    r"(?i)\bBeauty Salon\b",
    r"(?i)\bBeautician\b",
    r"(?i)\bSpa\b",
    r"(?i)\bClinic CoordinatorBesuty Therapist\b",
    r"(?i)\bStudio Medico Pisano\b",
    r"(?i)\bStudio Manager\b",
    r"(?i)\bProvider Owner Botox Beauty Spa Llc\b",
    r"(?i)\bMed Spa\b",
    r"(?i)\bMedSpa\b",
    r"(?i)\bMedspa\b",
    r"(?i)\bMedical Spa\b",
    r"(?i)\bMedicalSpa\b",
    r"(?i)\bMedicalspa\b",
    r"(?i)\bMedispa\b",
    r"(?i)\bHeadspa\b",
    r"(?i)\bHead spa\b",
    r"(?i)\bSpaMaster\b",
    r"(?i)\bSpa Master\b",
    r"(?i)\bMasterspa\b",
    r"(?i)\bMaster spa\b",
    r"(?i)\bMedics & Spa\b",
    r"(?i)\bMedicsSpa\b",
    r"(?i)\bMedics Spa\b",
    r"(?i)\bBesuty Therapist\b",
    r"(?i)\bBeauty Therapist\b",
    r"(?i)\bBeautyTherapist\b",

    # Misspellings & Typographical Errors
    r"(?i)\bMediacal\s?Spa\s?Manager\b",
    r"(?i)\bMedial\s?Spa\s?Manager\b",
    r"(?i)\bMedical\s?Sap\s?Manager\b",
    r"(?i)\bMedical\s?Spaa\s?Manager\b",
    r"(?i)\bMedical\s?Sspa\s?Manager\b",
    r"(?i)\bMedical\s?Spaaa\s?Manager\b",
    r"(?i)\bMedial\s?Spa\s?Manger\b",
    r"(?i)\bMedical\s?Spa\s?Manger\b",
    r"(?i)\bMedcial\s?Spa\s?Manager\b",
    r"(?i)\bMedical\s?Spa\s?Maneger\b",
    r"(?i)\bMedical\s?Spa\s?Managr\b",
    r"(?i)\bMedical\s?Spaa\s?Mngr\b",

    # Case Variations
    r"(?i)\bmedical spa manager\b",
    r"(?i)\bMedical spa manager\b",
    r"(?i)\bmedical Spa Manager\b",
    r"(?i)\bMEDICAL SPA MANAGER\b",
    r"(?i)\bMeDical Spa ManaGer\b",

    # Spanish Variants
    r"(?i)\bGerente\s?de\s?Spa\s?Médico\b",
    r"(?i)\bAdministrador\s?de\s?Spa\s?Médico\b",
    r"(?i)\bDirector\s?de\s?Spa\s?Médico\b",
    r"(?i)\bEncargado\s?de\s?Spa\s?Médico\b",
    r"(?i)\bGerente\s?de\s?Bienestar\s?Médico\b",
    r"(?i)\bCoordinador\s?de\s?Spa\s?Médico\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bAesthetic\s?Spa\s?Manager\b",
    r"(?i)\bCosmetic\s?Spa\s?Manager\b",
    r"(?i)\bWellness\s?Spa\s?Manager\b",
    r"(?i)\bLuxury\s?Spa\s?Manager\b",
    r"(?i)\bSpa\s?Medical\s?Director\b",
    r"(?i)\bMedical\s?Day\s?Spa\s?Manager\b",
    r"(?i)\bWellness Specialist\b",
]

# Exact matches that should be updated
spa_exact_matches = {
    "Medical Spa Manager",
    "Med Spa Manager",
    "Spa Medical Manager",
    "Medical Aesthetic Spa Manager",
    "Manager of Medical Spa",
    "Director of Medical Spa",
    "Medical Wellness Spa Manager",
    "Spa Manager (Medical)",
    "Mediacal Spa Manager",
    "Medial Spa Manager",
    "Medical Sap Manager",
    "Medical Spaa Manager",
    "Medical Sspa Manager",
    "Medical Spaaa Manager",
    "Medial Spa Manger",
    "Medical Spa Manger",
    "Medcial Spa Manager",
    "Medical Spa Maneger",
    "Medical Spa Managr",
    "Medical Spaa Mngr",
    "Gerente de Spa Médico",
    "Administrador de Spa Médico",
    "Director de Spa Médico",
    "Encargado de Spa Médico",
    "Gerente de Bienestar Médico",
    "Coordinador de Spa Médico",
    "Aesthetic Spa Manager",
    "Cosmetic Spa Manager",
    "Wellness Spa Manager",
    "Luxury Spa Manager",
    "Spa Medical Director",
    "Medical Day Spa Manager",
    "Beauty",
    'AROMATHERAPY SPECIALIST',
    'CPMT LASER company s Guest',
}

# # Define patterns (these should NOT be changed)
# spa_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

spa_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Medical Spa Manager
mask_spa = df['speciality'].str.contains('|'.join(spa_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(spa_exact_matches)

# mask_spa_exclusions = df['speciality'].str.contains(spa_exclusions, case=False, na=False, regex=True)
mask_spa_exclusions = df['speciality'].isin(spa_exclusions)

# Final mask: Select Medical Spa Manager
mask_spa_final = mask_spa & ~mask_spa_exclusions

# Store the original values that will be replaced
original_spa_values = df.loc[mask_spa_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_spa_final, 'speciality'] = 'Medical Spa Manager'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Medical Spa Manager", 'green'))
print(df.loc[mask_spa_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_spa_values = df.loc[mask_spa_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Medical Spa Manager", "cyan"))
for original_spa_value in original_spa_values:
    print(f"✅ {original_spa_value} → Medical Spa Manager")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Medical Spa Manager:", 'red'))
print(grouped_spa_values)

# Print summary
matched_count_spa = mask_spa_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Medical Spa Manager: "
        f"{matched_count_spa}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Nutritionist related titles

nutritionist_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bNutritionist\b",
    r"(?i)\bRegistered\s?Dietitian\b",
    r"(?i)\bDietitian\b",
    r"(?i)\bClinical\s?Nutritionist\b",
    r"(?i)\bCertified\s?Nutritionist\b",
    r"(?i)\bSports\s?Nutritionist\b",
    r"(?i)\bFunctional\s?Nutritionist\b",
    r"(?i)\bHolistic\s?Nutritionist\b",
    r"(?i)\bNutritional\s?Therapist\b",
    r"(?i)\bDietary\s?Consultant\b",
    r"(?i)Nutrition",
    r"(?i)\bMedica Nutrologa\b",
    r"(?i)Nutrologa",
    r"(?i)\bNutraceutical Professional\b",
    r"(?i)\bLic  Nutricion Y Estetica\b",
    r"(?i)\bDietician Acne & Skinhealth\b",
    r"(?i)\bNutrologo\b",

    # Misspellings & Typographical Errors
    r"(?i)\bNutricionist\b",
    r"(?i)\bNutrisionist\b",
    r"(?i)\bNutritonist\b",
    r"(?i)\bNutritianist\b",
    r"(?i)\bNutricianist\b",
    r"(?i)\bNutrishionist\b",
    r"(?i)\bNutricionista\b",
    r"(?i)\bNutritionest\b",
    r"(?i)\bNutriconist\b",

    # Case Variations
    r"(?i)\bnutritionist\b",
    r"(?i)\bNutritionist\b",
    r"(?i)\bNUTRITIONIST\b",
    r"(?i)\bNutritionIST\b",

    # Spanish Variants
    r"(?i)\bNutricionista\b",
    r"(?i)\bEspecialista\s?en\s?Nutrición\b",
    r"(?i)\bDietista\b",
    r"(?i)\bExperto\s?en\s?Nutrición\b",
    r"(?i)\bConsultor\s?de\s?Nutrición\b",

    # Other Possible Variations (Including Doctor/Specialist Forms)
    r"(?i)\bDoctor\s?of\s?Nutrition\b",
    r"(?i)\bPhD\s?in\s?Nutrition\b",
    r"(?i)\bFood\s?Scientist\b",
    r"(?i)\bHealth\s?Coach\b",
    r"(?i)\bIntegrative\s?Nutritionist\b",
    r"(?i)\bNutritional\s?Health\s?Consultant\b",
    r"(?i)\bSupplements\b",
    r"(?i)\bDieticionist\b",
]

# Exact matches that should be updated
nutritionist_exact_matches = {
    "Nutritionist",
    "Registered Dietitian",
    "Dietitian",
    "Clinical Nutritionist",
    "Certified Nutritionist",
    "Sports Nutritionist",
    "Functional Nutritionist",
    "Holistic Nutritionist",
    "Nutritional Therapist",
    "Dietary Consultant",
    "Nutricionist",
    "Nutrisionist",
    "Nutritonist",
    "Nutritianist",
    "Nutricianist",
    "Nutrishionist",
    "Nutricionista",
    "Nutritionest",
    "Nutriconist",
    "Especialista en Nutrición",
    "Dietista",
    "Experto en Nutrición",
    "Consultor de Nutrición",
    "Doctor of Nutrition",
    "PhD in Nutrition",
    "Food Scientist",
    "Health Coach",
    "Integrative Nutritionist",
    "Nutritional Health Consultant",
}

# # Define patterns (these should NOT be changed)
# nutritionist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

nutritionist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Nutritionist
mask_nutritionist = df['speciality'].str.contains('|'.join(nutritionist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(nutritionist_exact_matches)

# mask_nutritionist_exclusions = df['speciality'].str.contains(nutritionist_exclusions, case=False, na=False, regex=True)
mask_nutritionist_exclusions = df['speciality'].isin(nutritionist_exclusions)

# Final mask: Select Nutritionist
mask_nutritionist_final = mask_nutritionist & ~mask_nutritionist_exclusions

# Store the original values that will be replaced
original_nutritionist_values = df.loc[mask_nutritionist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_nutritionist_final, 'speciality'] = 'Nutritionist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Nutritionist", 'green'))
print(df.loc[mask_nutritionist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_nutritionist_values = df.loc[mask_nutritionist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Nutritionist", "cyan"))
for original_nutritionist_value in original_nutritionist_values:
    print(f"✅ {original_nutritionist_value} → Nutritionist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Nutritionist:", 'red'))
print(grouped_nutritionist_values)

# Print summary
matched_count_nutritionist = mask_nutritionist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Nutritionist: "
        f"{matched_count_nutritionist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Professor Teacher related titles

professor_variants = [
    # Standard Titles & Variants
    r"(?i)\bProfessor Teacher\b",
    r"(?i)\bProfessor & Teacher\b",
    r"(?i)\bProfessor-Teacher\b",
    r"(?i)\bProfessor / Teacher\b",
    r"(?i)\bProf. Teacher\b",
    r"(?i)\bProf Teacher\b",
    r"(?i)\bProf.\b",
    r"(?i)\bProfessor\b",
    r"(?i)\bTeacher\b",
    r"(?i)\bTrainer\b",
    r"(?i)\bPhd\b",
    r"(?i)\bEducation\b",
    r"(?i)\bDean\b",
    r"(?i)\bPrinicpal\b",
    r"(?i)\bTeaching\b",
    r"(?i)\bProf\b",
    r"(?i)\bDean\b",
    r"(?i)\bAcademic\b",
    r"(?i)\bProfessir\b",
    r"(?i)\bCosmetologistTeacher\b",
    r"(?i)\bProgram Director\b",
    r"(?i)\bUniversity ProfessorOtolaryngologyFacial Plastic\b",

    # Misspellings & Typographical Errors
    r"(?i)\bProffesor Teacher\b",
    r"(?i)\bProfesor Teacher\b",
    r"(?i)\bProfesser Teacher\b",
    r"(?i)\bProfessar Teacher\b",
    r"(?i)\bProffesor Techer\b",
    r"(?i)\bProfessor Techer\b",
    r"(?i)\bProfesor Techer\b",
    r"(?i)\bProfesseur Teacher\b",
    r"(?i)\bProfessor Teachar\b",
    r"(?i)\bProf. Teachr\b",

    # Case Variations
    r"(?i)\bPROFESSOR TEACHER\b",
    r"(?i)\bprofessor teacher\b",
    r"(?i)\bProfEsSor TeaChEr\b",
    r"(?i)\bprOFesSor TeaCHer\b",

    # Spanish Variants
    r"(?i)\bProfesor Docente\b",
    r"(?i)\bProfesor Maestro\b",
    r"(?i)\bDocente Universitario\b",
    r"(?i)\bCatedrático Docente\b",
    r"(?i)\bProfesor Académico\b",
    r"(?i)\bInstructor Educativo\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bProfessor Docente\b",
    r"(?i)\bProfesor Teacher\b",
    r"(?i)\bProf Teacher Académico\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bSenior Professor Teacher\b",
    r"(?i)\bLead Professor Teacher\b",
    r"(?i)\bHead of Teaching & Professorship\b",
    r"(?i)\bAcademic Professor\b",
    r"(?i)\bEducational Professor\b",
    r"(?i)\bUniversity Professor Teacher\b",
    r"(?i)\bLecturer & Professor\b",
    r"(?i)\bTeaching Professor\b",
    r"(?i)\bMA\b",
    r"(?i)\bM A\b",
    r"(?i)\bMa\b",
    r"(?i)\bProfessorTeacher\b",
    r"(?i)\bAcademic Program Administrator\b",
    r"(?i)\bKazakh National Medical University\b",
    r"(?i)\bEducator\b",
]

# Exact matches that should be updated
professor_exact_matches = {
    "Professor Teacher",
    "Professor & Teacher",
    "Professor-Teacher",
    "Professor / Teacher",
    "Prof. Teacher",
    "Prof Teacher",
    "Proffesor Teacher",
    "Professer Teacher",
    "Professar Teacher",
    "Proffesor Techer",
    "Professor Techer",
    "Profesor Techer",
    "Professeur Teacher",
    "Professor Teachar",
    "Prof. Teachr",
    "Profesor Docente",
    "Profesor Maestro",
    "Docente Universitario",
    "Catedrático Docente",
    "Profesor Académico",
    "Instructor Educativo",
    "Professor Docente",
    "Profesor Teacher",
    "Prof Teacher Académico",
    "Senior Professor Teacher",
    "Lead Professor Teacher",
    "Head of Teaching & Professorship",
    "Academic Professor",
    "Educational Professor",
    "University Professor Teacher",
    "Lecturer & Professor",
    "Teaching Professor",
    "Principal",
    "ProfessorTeacher",
    'Course Coordinator',
    'Master Of Science',
    'Adjunct Instructor',
    'Director Riphah International University Islamabad-Pakistan',
    'Learning & Development',
    'Assistant ProfessorMD',
    'Mf',
    'Cosmetology Instructor',
    'Cosmetology Career Technology Instructor',
    'Cosmetology1 Instructor',
    'High School Cosmetology Instructor',
    'Instructor Of Cosmetology',
    'Vocational Instructor Of Cosmetology',
    'Director PIR Training',
}

# # Define patterns (these should NOT be changed)
# professor_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

professor_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Sales Trainer',
    'Rn Clinical Trainer',
}

# Create a mask for Professor Teacher
mask_professor = df['speciality'].str.contains('|'.join(professor_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(professor_exact_matches)

# mask_professor_exclusions = df['speciality'].str.contains(professor_exclusions, case=False, na=False, regex=True)
mask_professor_exclusions = df['speciality'].isin(professor_exclusions)

# Final mask: Select Professor Teacher
mask_professor_final = mask_professor & ~mask_professor_exclusions

# Store the original values that will be replaced
original_professor_values = df.loc[mask_professor_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_professor_final, 'speciality'] = 'Professor Teacher'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Professor Teacher", 'green'))
print(df.loc[mask_professor_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_professor_values = df.loc[mask_professor_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Professor Teacher", "cyan"))
for original_professor_value in original_professor_values:
    print(f"✅ {original_professor_value} → Professor Teacher")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Professor Teacher:", 'red'))
print(grouped_professor_values)

# Print summary
matched_count_professor = mask_professor_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Professor Teacher: "
        f"{matched_count_professor}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Dental Surgeon related titles

dental_surgeon_variants = [
    # Standard title variations
    r"(?i)\bDental\s?Surgeon\b",
    r"(?i)\bCosmetic\s?Dental\s?Surgeon\b",
    r"(?i)\bGeneral\s?Dental\s?Surgeon\b",
    r"(?i)\bDDS\b",
    r"(?i)\bD D S\b",
    r"(?i)\bCosmetic Dentition\b",
    r"(?i)\bDental Surgron\b",
    r"(?i)\bDentistDental Surgeon\b",
    r"(?i)\bCirurgia Dentista\b",
    r"(?i)\bDentist Surgeon\b",
    r"(?i)\bCirurgiao Dentista\b",
    r"(?i)\bFarmacist & Dentist Surgery\b",
    r"(?i)\bChirurgien Dentiste\b",
    r"(?i)\bCirujana Dentista\b",
    r"(?i)\bCirugia Dentista\b",
    r"(?i)\bCirurgia-Dentista\b",
    r"(?i)\bDental Surgery\b",
    r"(?i)\bCirugia Dentista Hof\b",
    r"(?i)\bDental Surgey\b",

    # Common misspellings and case mistakes
    r"(?i)\bDentel\s?Surgeon\b",

    # Variants in Spanish and other languages
    r"(?i)\bCirujano\s?Dental\b",
    r"(?i)\bCirujano\s?Dentista\b",

    # Other possible variations (including specialist forms)
    r"(?i)\bCertified\s?Dental\s?Surgeon\b",
    r"(?i)\bLicensed\s?Dental\s?Surgeon\b",
    r"(?i)\bSpecialist\s?Dental\s?Surgeon\b",
    r"(?i)\bRegistered\s?Dental\s?Surgeon\b",
]

# Exact matches that should be updated
dental_surgeon_exact_matches = {
    r"(?i)\bDentel\s?Surgeon\b",
    r"(?i)\bCirujano\s?Dental\b",
    r"(?i)\bCirujano\s?Dentista\b",
}

# Define patterns (these should NOT be changed)
dental_surgeon_exclusions = [
    r"(?i)\bMaxillo\s?Facial\b",
    r"(?i)\bMaxillo-Facial\b"
] # maxillo variants

# Create a mask for Dental Surgeon
mask_dental_surgeon = df['speciality'].str.contains('|'.join(dental_surgeon_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(dental_surgeon_exact_matches)
mask_dental_surgeon_exclusions = df['speciality'].isin(dental_surgeon_exclusions)

# Final mask: Select Dental Surgeon
mask_dental_surgeon_final = mask_dental_surgeon & ~mask_dental_surgeon_exclusions

# Store the original values that will be replaced
original_dental_surgeon_values = df.loc[mask_dental_surgeon_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_dental_surgeon_final, 'speciality'] = 'Dental Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Dental Surgeon", 'green'))
print(df.loc[mask_dental_surgeon_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_dental_surgeon_values = df.loc[mask_dental_surgeon_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Dental Surgeon", "cyan"))
for original_dental_surgeon_value in original_dental_surgeon_values:
    print(f"✅ {original_dental_surgeon_value} → Dental Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Dental Surgeon:", 'red'))
print(grouped_dental_surgeon_values)

# Print summary
matched_count_dental_surgeon = mask_dental_surgeon_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Dental Surgeon: "
        f"{matched_count_dental_surgeon}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Pharmacist related titles

pharmacist_variants = [
    # Standard Titles & Variants
    r"(?i)\bPharmacist\b",
    r"(?i)\bPharmacy Specialist\b",
    r"(?i)\bClinical Pharmacist\b",
    r"(?i)\bCommunity Pharmacist\b",
    r"(?i)\bHospital Pharmacist\b",
    r"(?i)\bPharmacological Specialist\b",
    r"(?i)\bPharmaceutical Professional\b",
    r"(?i)\bPharmacy Doctor\b",
    r"(?i)\bLicensed Pharmacist\b",
    r"(?i)\bPharmacist Consultant\b",
    r"(?i)\bConsultant Pharmacist\b",
    r"(?i)\bPharmacy\b",
    r"(?i)\bPharma\b",
    r"(?i)\bPharmd\b",
    r"(?i)\bM8Pharma\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPharmicist\b",
    r"(?i)\bFarmacist\b",
    r"(?i)\bPhamacist\b",
    r"(?i)\bPharmasist\b",
    r"(?i)\bPharmocist\b",
    r"(?i)\bPharacist\b",
    r"(?i)\bPharmacisst\b",

    # Case Variations
    r"(?i)\bpharmacist\b",
    r"(?i)\bPHARMACIST\b",
    r"(?i)\bPhArMaCiSt\b",
    r"(?i)\bPhArMacIst\b",

    # Spanish Variants
    r"(?i)\bFarmacéutico\b",
    r"(?i)\bFarmacéutica\b",
    r"(?i)\bFarmacéutico\s?Clínico\b",
    r"(?i)\bFarmacéutico\s?Comunitario\b",
    r"(?i)\bFarmacéutico\s?Hospitalario\b",
    r"(?i)\bEspecialista\s?Farmacéutico\b",
    r"(?i)\bDoctor\s?Farmacéutico\b",
    r"(?i)\bFarmacéutico\s?Consultor\b",
    r"(?i)\bConsultor\s?Farmacéutico\b",
    r"(?i)\bProfesional\s?Farmacéutico\b",
    r"(?i)\bFarmacia\s?Clínica\b",

    # Other Possible Variations
    r"(?i)\bPharmacy Professional\b",
    r"(?i)\bPharmacy Consultant\b",
    r"(?i)\bPharmaceutical Practitioner\b",
    r"(?i)\bPharmaceutical Care Specialist\b",
    r"(?i)\bPharmaceutical Practitioner\b",
    r"(?i)Farmaceutica",
    r"(?i)\bFarmalider\b",
]

# Exact matches that should be updated
pharmacist_exact_matches = {
    "Pharmacist",
    "Pharmacy Specialist",
    "Clinical Pharmacist",
    "Community Pharmacist",
    "Hospital Pharmacist",
    "Pharmacological Specialist",
    "Pharmaceutical Professional",
    "Pharmacy Doctor",
    "Licensed Pharmacist",
    "Pharmacist Consultant",
    "Consultant Pharmacist",
    "Pharmicist",
    "Farmacist",
    "Phamacist",
    "Pharmasist",
    "Pharmocist",
    "Pharacist",
    "Pharmacisst",
    "Farmacéutico",
    "Farmacéutica",
    "Farmacéutico Clínico",
    "Farmacéutico Comunitario",
    "Farmacéutico Hospitalario",
    "Especialista Farmacéutico",
    "Doctor Farmacéutico",
    "Farmacéutico Consultor",
    "Consultor Farmacéutico",
    "Profesional Farmacéutico",
    "Farmacia Clínica",
    "Pharmacy Professional",
    "Pharmacy Consultant",
    "Pharmaceutical Practitioner",
    "Pharmaceutical Care Specialist",
    'Apothecary',
    'Pharmacists',
    'D Pham',
    'PharmacistClinical Staff',
}

# # Define patterns (these should NOT be changed)
# pharmacist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

pharmacist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Pharma Sales Manager',
}

# Create a mask for Pharmacist
mask_pharmacist = df['speciality'].str.contains('|'.join(pharmacist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(pharmacist_exact_matches)

# mask_pharmacist_exclusions = df['speciality'].str.contains(pharmacist_exclusions, case=False, na=False, regex=True)
mask_pharmacist_exclusions = df['speciality'].isin(pharmacist_exclusions)

# Final mask: Select Pharmacist
mask_pharmacist_final = mask_pharmacist & ~mask_pharmacist_exclusions

# Store the original values that will be replaced
original_pharmacist_values = df.loc[mask_pharmacist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_pharmacist_final, 'speciality'] = 'Pharmacist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Pharmacist", 'green'))
print(df.loc[mask_pharmacist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_pharmacist_values = df.loc[mask_pharmacist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Pharmacist", "cyan"))
for original_pharmacist_value in original_pharmacist_values:
    print(f"✅ {original_pharmacist_value} → Pharmacist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Pharmacist:", 'red'))
print(grouped_pharmacist_values)

# Print summary
matched_count_pharmacist = mask_pharmacist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Pharmacist: "
        f"{matched_count_pharmacist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for anti_aging_physician related titles

anti_aging_physician_variants = [
    r"(?i)\bAnti-aging\s?Physician\b",
    r"(?i)\bAnti Aging\s?Physician\b",
    r"(?i)\bAnti-aging\s?Doctor\b",
    r"(?i)\bAnti Aging\s?Doctor\b",
    r"(?i)\bAnti-aging\s?Medical\s?Doctor\b",
    r"(?i)\bAnti Aging\s?Medical\s?Doctor\b",
    r"(?i)\bAnti-aging\s?Specialist\b",
    r"(?i)\bAnti Aging\s?Specialist\b",
    r"(?i)\bAnti-aging\s?Medicine\s?Physician\b",
    r"(?i)\bAnti Aging\s?Medicine\s?Physician\b",
    r"(?i)\bAnti-aging\s?Physician\s?Specialist\b",
    r"(?i)\bAnti Aging\s?Physician\s?Specialist\b",
    r"(?i)\bAnti-aging\s?Doctor\s?Specialist\b",
    r"(?i)\bAnti Aging\s?Doctor\s?Specialist\b",
    r"(?i)\bAnti-Aging Practitioner\b",
    r"(?i)\bAnti-Aging Physician\b",
    r"(?i)\bAge Management\b",
    r"(?i)\bLongevity Expert\b",
    r"(?i)\bMedecine Morphologique Et Anti Age\b",
    r"(?i)\bRj Medicina Estetica & Longevidade\b",
    r"(?i)\bEsthetics & Antiaging Medicine\b",
    r"(?i)\bAnti-Aging & Regenerative Medicine\b",
]

# Exact matches that should be updated
anti_aging_physician_exact_matches = {
    'Anti-aging Physician',
    'Anti-Aging Physician',
    'Anti-Aging physician',
    'Anti Aging Physician',
    'Anti-aging Doctor',
    'Anti-Aging Practitioner',
    'Anti-Aging Physician',
    'Anti Aging',
    'Anti-Aging',
    'Anti Aging Doctor',
    'Anti-aging Medical Doctor',
    'Anti Aging Medical Doctor',
    'Anti-aging Specialist',
    'Anti Aging Specialist',
    'Anti-aging Medicine Physician',
    'Anti Aging Medicine Physician',
    'Anti-aging Physician Specialist',
    'Anti Aging Physician Specialist',
    'Anti-aging Doctor Specialist',
    'Anti Aging Doctor Specialist',
    'Anti-aging Medicine Specialist',
    'Anti Aging Medicine Specialist',
    'Anti-aging Physician Expert',
    
    # Case-related errors
    'anti-aging physician',
    'anti aging physician',
    'ANTI-AGING PHYSICIAN',
    'ANTI AGING PHYSICIAN',
    'AnTi-AgiNg PhYsIcIaN',

    # Common misspellings
    'Anti-aging Physcian',
    'Anti-aging Phyisician',
    'Anti-agng Physician',
    'Anti Agng Physician',
    'Antiaging Physician',
    'Anti-Aging Phyisician',
    'AntiAging Physician',
    'Anti-Aging Physcian',
    'Anti-Aging Physicians',
    'Ant-aging Physician',
    'Anti-agin Physician',

    # Spanish-related exclusions
    'Médico Anti-envejecimiento',
    'Especialista en Anti-envejecimiento',
    'Doctor en Anti-envejecimiento',
    'Médico Anti-Aging',
    'Especialista Anti-Aging',
    'Doctor Anti-Aging',
    'Médico Anti-aging',
    'Especialista en Medicina Anti-envejecimiento',
    'Especialista en Medicina Anti-Aging',
    
    # Anti-Aging Practitioner
    "Anti-aging Practicioner",
    "Anti-aging Practitoner",
    "Anti-Aging Practicioner",
    "Anti-Aging Pracitioner",
    "Anti-aging Prctitioner",
    "AntiAging Practitioner",
    "Anti-Aging Practtioner",
    "Anti-aging Practitiner",
    "Anti-Aging Practicioners",
    "Anti-agng Practitioner",
    "Anti-agin Practitioner",
    'Anti-Aging Physician',
    'Anti Aging Medicine',
    'Antiaging',
    'Anti-Aging Skincare',
    'Medicine -Primary-Holistic-Antiaging',
    'Anti- Aging Medicine',
    'Anti-Ageing',
    'Anti Aging Dan Stem Cell',
    'Anti-Ageing Medicine',
    'Anti-AgingFunctional Med',
    'Antiaging Practitioner',
    'Antibaging doctor',
    'Anti-Ageing Physician',
    'ANTIAGING DOCTOR',
}

# Define patterns for  & Resident & Professor (these should NOT be changed)
anti_aging_physician_exclusions = {
    'Aesthetic & Anti-aging Physician',
    'Aesthetic & Anti Aging Physician',
    'Aesthetic & AntiAging Physician',
    'Aesthetic & Antiaging Physician',
    'Aesthetic & Anti Aging Practitioner',
    'Aesthetic & AntiAging Practitioner',
    'Aesthetic & Antiaging Practitioner',
    'Aesthetic Anti-Aging Physician',
    'Aesthetic Anti Aging Physician',
    'Aesthetic AntiAging Physician',
    'Aesthetic Antiaging Physician',
    'Aesthetic Anti Aging Medical Doctor',
    'Aesthetic AntiAging Medical Doctor',
    'Aesthetic Antiaging Medical Doctor',
    'Aesthetic Anti Aging Specialist',
    'Aesthetic AntiAging Specialist',
    'Aesthetic Antiaging Specialist',
    'Aesthetic Anti Aging Doctor',
    'Aesthetic AntiAging Doctor',
    'Aesthetic Antiaging Doctor',
    'Aesthetic Anti Aging Surgeon',
    'Aesthetic AntiAging Surgeon',
    'Aesthetic Antiaging Surgeon',
    'Anti-Aging Aesthetic Physician',
    'Anti-Aging Aesthetic Practitioner',
    'Anti Aging Aesthetic Physician',
    'Anti Aging Aesthetic Practitioner',
    'Aesthetic & Anti Aging Medical Practitioner',
    'Aesthetic & AntiAging Medical Practitioner',
    'Aesthetic & Antiaging Medical Practitioner',
    'Aesthetic & Anti Aging Healthcare Practitioner',
    'Aesthetic & AntiAging Healthcare Practitioner',
    'Aesthetic & Antiaging Healthcare Practitioner',
    'Aesthetic Anti Aging Aesthetician',
    'Aesthetic & Anti Aging Medical Specialist',
    'Aesthetic & AntiAging Medical Specialist',
    'Aesthetic & Antiaging Medical Specialist',
    'Aesthetic & Anti-Aging Physician',
# Variations for common typos and case mistakes
    'Aesthetic & Anti-Aging Physician',
    'Aesthetic & AntiAging Physiican',
    'Aesthetic Anti-Aging Physican',
    'Aesthetic Anti Aging Physcian',
    'Aesthetic Anti Aging Pracitioner',
    'Aesthetic Anti-Aging Medical Doctor',
    'Aesthetic AntiAging Medical Dotor',
    'Aesthetic Anti Aging Speciallist',
    'Aesthetic Anti Aging Pracitioner',
    'Aesthetic Anti Aging Practicioner',
    'Aesthetic AntiAging Pracitioner',
    'Aesthetic Antiaging Medical Doctor',
    'Aesthetic AntiAging Surgeion',
    'Aesthetic Anti Aging Medcial Specalist',
    'Aesthetic Anti Aging Physican',
    'Aesthetic Anti-Aging Speciallist',
    'Aesthetic Anti Aging Healthcare Practicioner',
    'Aesthetic AntiAging Specilist',
    'Aesthetic Anti Aging Aesthetician',
    'Aesthetic AntiAging Surgeion',
    'Aesthetic Antiaging Doctor',
    'Aesthetic Antiaging Healthcare Specialist',
    'Aesthetic & Anti-Aging Practicioner',
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern', 'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Aesthetic&Anti-Aging Physcian',
    'Anti Aging Center Manager',
    'Nurse Antiaging',
    'Plastic Surgeon - Antiaging Practicioner',
    'Antiaging Nutrition',
    'Dermatologist & Anti-Aging Specialist',
    'Anti-Aging & Sports Medicine',
    'Gynecologist & Anti Aging Physician',
    }

# Create a mask for Anti-aging Physician
mask_anti_aging_physician = df['speciality'].str.contains('|'.join(anti_aging_physician_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(anti_aging_physician_exact_matches)
mask_anti_aging_physician_exclusions = df['speciality'].isin(anti_aging_physician_exclusions)

# Final mask: Select Anti-aging Physician
mask_anti_aging_physician_final = mask_anti_aging_physician & ~mask_anti_aging_physician_exclusions

# Store the original values that will be replaced
original_anti_aging_physician_values = df.loc[mask_anti_aging_physician_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_anti_aging_physician_final, 'speciality'] = 'Anti-aging Physician'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Anti-aging Physician", 'green'))
print(df.loc[mask_anti_aging_physician_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_anti_aging_physician_values = df.loc[mask_anti_aging_physician_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Anti-aging Physician", "cyan"))
for original_anti_aging_physician_value in original_anti_aging_physician_values:
    print(f"✅ {original_anti_aging_physician_value} → Anti-aging Physician")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Anti-aging Physician:", 'red'))
print(grouped_anti_aging_physician_values)

# Print summary
matched_count_anti_aging_physician = mask_anti_aging_physician_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Anti-aging Physician: "
        f"{matched_count_anti_aging_physician}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Facial Plastic Surgeon related titles

facial_plastic_surgeon_variants = [
    r"(?i)\bFacial\s?Plastic\s?Surgeon\b",
    r"(?i)\bFacial\s?Aesthetic\s?Surgeon\b",
    r"(?i)\bFacial\s?Reconstructive\s?Surgeon\b",
    r"(?i)\bFacial\s?Cosmetic\s?Surgeon\b",
    r"(?i)\bAesthetic\s?Facial\s?Surgeon\b",
    r"(?i)\bCosmetic\s?Facial\s?Surgeon\b",

    # Spanish variants
    r"(?i)\bCirujano\s?Plástico\s?Facial\b",
    r"(?i)\bCirujano\s?Estético\s?Facial\b",
    r"(?i)\bCirujano\s?Reconstructivo\s?Facial\b",
    r"(?i)\bCirujano\s?Cosmético\s?Facial\b",
    r"(?i)\bEspecialista\s?en\s?Cirugía\s?Plástica\s?Facial\b",
    r"(?i)\bCirujano\s?Facial\s?Estético\b",
    r"(?i)\bCirujano\s?Facial\s?Cosmético\b",

    # Other possible variations
    r"(?i)\bDoctor\s?in\s?Facial\s?Plastic\s?Surgery\b",
    r"(?i)\bBoard\s?Certified\s?Facial\s?Plastic\s?Surgeon\b",
    r"(?i)\bCertified\s?Facial\s?Plastic\s?Surgeon\b",
    r"(?i)\bCosmetic\s?Plastic\s?Surgeon\s?Specialist\b",
    r"(?i)\bFacial\s?Reconstructive\s?Surgeon\s?Specialist\b",
    r"(?i)\bAesthetic\s?Plastic\s?Surgeon\b",
    r"(?i)\bFacial\s?Surgery\s?Specialist\b",
    r"(?i)\bPlastic\s?Surgical\s?Specialist\b",
    r"(?i)\bFacial Plastic Surgery\b",
    r"(?i)\bOculofacial Plastics\b",
    r"(?i)\bCx Plastico Facial\b",
    r"(?i)\bRhinoplasty\b",
    r"(?i)\bPlastic Surgeon   Facial Plastic Surgeon\b",
    r"(?i)\bBreast & Facial Surgery\b",
    r"(?i)\bCirujano Facial\b",
]

# Exact matches that should be updated
facial_plastic_surgeon_exact_matches = {
    "Facial Plastic Surgeon",
    "Facial Aesthetic Surgeon",
    "Facial Reconstructive Surgeon",
    "Facial Cosmetic Surgeon",
    "Aesthetic Facial Surgeon",
    "Cosmetic Facial Surgeon",
    # Spanish form matches
    "Cirujano Plástico Facial",
    "Cirujano Estético Facial",
    "Cirujano Reconstructivo Facial",
    "Cirujano Cosmético Facial",
    "Especialista en Cirugía Plástica Facial",
    "Cirujano Facial Estético",
    "Cirujano Facial Cosmético",
    # Other possible variations
    "Doctor in Facial Plastic Surgery",
    "Board Certified Facial Plastic Surgeon",
    "Certified Facial Plastic Surgeon",
    "Cosmetic Plastic Surgeon Specialist",
    "Facial Reconstructive Surgeon Specialist",
    "Aesthetic Plastic Surgeon",
    "Facial Surgery Specialist",
    "Plastic Surgical Specialist",
    "Facial Aesthetics",
    'Facial Plastics',
}

# Define patterns (these should NOT be changed)
facial_plastic_surgeon_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Facial Plastic Surgeon
mask_facial_plastic_surgeon = df['speciality'].str.contains('|'.join(facial_plastic_surgeon_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(facial_plastic_surgeon_exact_matches)
mask_facial_plastic_surgeon_exclusions = df['speciality'].isin(facial_plastic_surgeon_exclusions)

# Final mask: Select Facial Plastic Surgeon
mask_facial_plastic_surgeon_final = mask_facial_plastic_surgeon & ~mask_facial_plastic_surgeon_exclusions

# Store the original values that will be replaced
original_facial_plastic_surgeon_values = df.loc[mask_facial_plastic_surgeon_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_facial_plastic_surgeon_final, 'speciality'] = 'Facial Plastic Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Facial Plastic Surgeon", 'green'))
print(df.loc[mask_facial_plastic_surgeon_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_facial_plastic_surgeon_values = df.loc[mask_facial_plastic_surgeon_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Facial Plastic Surgeon", "cyan"))
for original_facial_plastic_surgeon_value in original_facial_plastic_surgeon_values:
    print(f"✅ {original_facial_plastic_surgeon_value} → Facial Plastic Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Facial Plastic Surgeon:", 'red'))
print(grouped_facial_plastic_surgeon_values)

# Print summary
matched_count_facial_plastic_surgeon = mask_facial_plastic_surgeon_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Facial Plastic Surgeon: "
        f"{matched_count_facial_plastic_surgeon}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Nurse Practitioner (NP) related titles

NP_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bNurse\s?Practitioner\b",
    r"(?i)\bNurse\s?Practitioner\s?\(NP\)\b",
    r"(?i)\bNP\b",
    r"(?i)\bNurse Practitioner NP\b",
    r"(?i)\bN P\b",
    r"(?i)\bn p\b",
    r"(?i)\bANP\b",
    r"(?i)\bFamily\s?Nurse\s?Practitioner\b",
    r"(?i)\bFNP\b",
    r"(?i)\bAdult\s?Nurse\s?Practitioner\b",
    r"(?i)\bPediatric\s?Nurse\s?Practitioner\b",
    r"(?i)\bPsychiatric\s?Nurse\s?Practitioner\b",
    r"(?i)\bGeriatric\s?Nurse\s?Practitioner\b",
    r"(?i)\bNurse Injector\b",
    r"(?i)\bCosmetic Nurse\b",
    r"(?i)\bStaff Nurse\b",
    r"(?i)\bNurse Prescriber\b",
    r"(?i)\bNursing\b",
    r"(?i)\bAesthetic Nurse PractitionerPrescriber\b",
    r"(?i)\bAesthetic Nurse SpecialistOwnee\b",
    r"(?i)\bAesthetic PracticionerNurse\b",
    r"(?i)\bCertified Nurse Midwifery\b",
    r"(?i)\bNuse\b",
    r"(?i)\bEsthetic Nurse\b",
    r"(?i)\bSpec  Nurse\b",
    r"(?i)\bStaffnurse\b",
    r"(?i)\bIndependent Nurse Presceriber\b",
    r"(?i)\bNursingGluta Infusions\b",

    # Misspellings & Typographical Errors
    r"(?i)\bNurs\s?Practitioner\b",
    r"(?i)\bNurse\s?Practioner\b",
    r"(?i)\bNurse\s?Pracktitioner\b",
    r"(?i)\bNurse\s?Practitonner\b",
    r"(?i)\bNurse\s?Practitoner\b",
    r"(?i)\bNurse\s?Pracktitioner\s?\(NP\)\b",
    r"(?i)\bNurse\s?Prakittioner\b",
    r"(?i)\bNurse\s?Practitionar\b",
    r"(?i)\bNurce\s?Practitioner\b",
    r"(?i)\bNurse\s?Prakitoner\b",

    # Case Variations
    r"(?i)\bnurse practitioner\b",
    r"(?i)\bNurse practitioner\b",
    r"(?i)\bnurse Practitioner\b",
    r"(?i)\bNURSE PRACTITIONER\b",
    r"(?i)\bNurse PRACTITIONER\b",
    r"(?i)\bnurse PRACTITIONER\b",

    # Spanish Variants
    r"(?i)\bEnfermero\s?Practicante\b",
    r"(?i)\bEnfermera\s?Practicante\b",
    r"(?i)\bPracticante\s?de\s?Enfermería\b",
    r"(?i)\bEspecialista\s?en\s?Enfermería\b",
    r"(?i)\bEnfermero\s?de\s?Atención\s?Primaria\b",

    # Other Possible Variations (Including Doctor/Specialist Forms)
    r"(?i)\bNurse\s?Clinician\b",
    r"(?i)\bSenior\s?Nurse\s?Practitioner\b",
    r"(?i)\bBoard\s?Certified\s?Nurse\s?Practitioner\b",
    r"(?i)\bCertified\s?Nurse\s?Practitioner\b",
    r"(?i)\bOwnerNurse Practitioner\b",
]

# Exact matches that should be updated
NP_exact_matches = {
    "Nurse Practitioner",
    "Nurse Practitioner (NP)",
    "NP",
    "Family Nurse Practitioner",
    "FNP",
    "Adult Nurse Practitioner",
    "Pediatric Nurse Practitioner",
    "Psychiatric Nurse Practitioner",
    "Geriatric Nurse Practitioner",
    "Nurs Practitioner",
    "Nurse Practioner",
    "Nurse Pracktitioner",
    "Nurse Practitonner",
    "Nurse Practitoner",
    "Nurse Pracktitioner (NP)",
    "Nurse Prakittioner",
    "Nurse Practitionar",
    "Nurce Practitioner",
    "Nurse Prakitoner",
    "Enfermero Practicante",
    "Enfermera Practicante",
    "Practicante de Enfermería",
    "Especialista en Enfermería",
    "Enfermero de Atención Primaria",
    "Nurse Clinician",
    "Senior Nurse Practitioner",
    "Board Certified Nurse Practitioner",
    "Certified Nurse Practitioner",
    "Injector",
    "Aesthetic PracticionerNurse",
    'Nurse Pracitioner',
    'Nurse Practicioner',
    'Nurs Practitionar',
    'Nrs Practitioner',
    'Cosmetologist & Studing Nurse',
    'Cosmetology Nurse',
    'Specialist Nurse',
    'Nurse Antiaging',
    'Nurse PractitionerMedical Director',
    'Lic  Enfermeria',
    'Wound Care Nurse',
    'DNM',
}

# # Define patterns (these should NOT be changed)
NP_exclusions = r'\b(?:ARNP)|(?:Advanced)|(?:Registered)|(?:Rn)|(?:RN)\b'

# NP_exclusions = {
#     'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
#     'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
#     'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
#     'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
# }

# Create a mask for Nurse Practitioner (NP)
mask_NP = df['speciality'].str.contains('|'.join(NP_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(NP_exact_matches)

mask_NP_exclusions = df['speciality'].str.contains(NP_exclusions, case=False, na=False, regex=True)
# mask_NP_exclusions = df['speciality'].isin(NP_exclusions)

# Final mask: Select Nurse Practitioner (NP)
mask_NP_final = mask_NP & ~mask_NP_exclusions

# Store the original values that will be replaced
original_NP_values = df.loc[mask_NP_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_NP_final, 'speciality'] = 'Nurse Practitioner (NP)'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Nurse Practitioner (NP)", 'green'))
print(df.loc[mask_NP_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_NP_values = df.loc[mask_NP_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Nurse Practitioner (NP)", "cyan"))
for original_NP_value in original_NP_values:
    print(f"✅ {original_NP_value} → Nurse Practitioner (NP)")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Nurse Practitioner (NP):", 'red'))
print(grouped_NP_values)

# Print summary
matched_count_NP = mask_NP_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Nurse Practitioner (NP): "
        f"{matched_count_NP}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Pharmacologist related titles

pharmacologist_variants = [
    # Standard Titles & Variants
    r"(?i)\bPharmacologist\b",
    r"(?i)\bPharmacological Expert\b",
    r"(?i)\bClinical Pharmacologist\b",
    r"(?i)\bPharmacology Specialist\b",
    r"(?i)\bPharmaceutical Scientist\b",
    r"(?i)\bPharmacologist Consultant\b",
    r"(?i)\bConsultant Pharmacologist\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPharmacollogist\b",
    r"(?i)\bPharmocologist\b",
    r"(?i)\bPharmocologist\b",
    r"(?i)\bPharmocologist\b",
    r"(?i)\bPharmacologist\b",
    r"(?i)\bPharmcologist\b",

    # Case Variations
    r"(?i)\bpharmacologist\b",
    r"(?i)\bPHARMACOLOGIST\b",
    r"(?i)\bPhArMaCoLoGiSt\b",
    r"(?i)\bPhArMaCoLoGiSt\b",

    # Spanish Variants
    r"(?i)\bFarmacólogo\b",
    r"(?i)\bFarmacológica\b",
    r"(?i)\bEspecialista\s?Farmacológico\b",
    r"(?i)\bFarmacología\s?Clínica\b",
    r"(?i)\bFarmacología\s?Comunitaria\b",
    r"(?i)\bFarmacología\s?Hospitalaria\b",
    r"(?i)\bFarmacólogo\s?Consultor\b",
    r"(?i)\bConsultor\s?Farmacológico\b",

    # Other Possible Variations
    r"(?i)\bPharmacological Researcher\b",
    r"(?i)\bPharmacologist Specialist\b",
    r"(?i)\bPharmaceutical Expert\b",
    r"(?i)\bPharmacology Researcher\b",
    r"(?i)Pharmacology",
]

# Exact matches that should be updated
pharmacologist_exact_matches = {
    "Pharmacologist",
    "Pharmacological Expert",
    "Clinical Pharmacologist",
    "Pharmacology Specialist",
    "Pharmaceutical Scientist",
    "Pharmacologist Consultant",
    "Consultant Pharmacologist",
    "Pharmacollogist",
    "Pharmocologist",
    "Pharmcologist",
    "Farmacólogo",
    "Farmacológica",
    "Especialista Farmacológico",
    "Farmacología Clínica",
    "Farmacología Comunitaria",
    "Farmacología Hospitalaria",
    "Farmacólogo Consultor",
    "Consultor Farmacológico",
    "Pharmacological Researcher",
    "Pharmacologist Specialist",
    "Pharmaceutical Expert",
    "Pharmacology Researcher",
}

# # Define patterns (these should NOT be changed)
# pharmacologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

pharmacologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Pharmacologist
mask_pharmacologist = df['speciality'].str.contains('|'.join(pharmacologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(pharmacologist_exact_matches)

# mask_pharmacologist_exclusions = df['speciality'].str.contains(pharmacologist_exclusions, case=False, na=False, regex=True)
mask_pharmacologist_exclusions = df['speciality'].isin(pharmacologist_exclusions)

# Final mask: Select Pharmacologist
mask_pharmacologist_final = mask_pharmacologist & ~mask_pharmacologist_exclusions

# Store the original values that will be replaced
original_pharmacologist_values = df.loc[mask_pharmacologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_pharmacologist_final, 'speciality'] = 'Pharmacologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Pharmacologist", 'green'))
print(df.loc[mask_pharmacologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_pharmacologist_values = df.loc[mask_pharmacologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Pharmacologist", "cyan"))
for original_pharmacologist_value in original_pharmacologist_values:
    print(f"✅ {original_pharmacologist_value} → Pharmacologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Pharmacologist:", 'red'))
print(grouped_pharmacologist_values)

# Print summary
matched_count_pharmacologist = mask_pharmacologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Pharmacologist: "
        f"{matched_count_pharmacologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Maxillofacial Surgeon related titles

maxillofacial_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bMaxillofacial\s?Surgeon\b",
    r"(?i)\bMaxillofacial\s?Surg\b",
    r"(?i)\bMaxFac\s?Surgeon\b",
    r"(?i)\bBucomaxillofacial Surgery\b",
    r"(?i)\bBuco Maxilo Facial\b",
    r"(?i)\bMaxillo Facial Surgeon\b",
    r"(?i)\bMaxillo-Facial Surgeon\b",
    r"(?i)\bMaxilo Facial\b",
    r"(?i)\bMaxilofacial Surgery\b",
    r"(?i)\bMaxillary Facial Surgery\b",
    r"(?i)\bChirurgie Maxillo-Faciale\b",
    r"(?i)\bChirurgie Maxillo Faciale\b",
    r"(?i)\bOrl Et Chirurgie Cervico Faciale\b",

    # Misspellings & Typographical Errors
    r"(?i)\bMaxilofacial\s?Surgeon\b",
    r"(?i)\bMaxillofascial\s?Surgeon\b",
    r"(?i)\bMaxillofacil\s?Surgeon\b",
    r"(?i)\bMaxillofascial\s?Surgon\b",
    r"(?i)\bMaxillofascial\s?Surgin\b",
    r"(?i)\bMaxillofacial\s?Surjeon\b",
    r"(?i)\bMaxillofacial\s?Surgan\b",
    r"(?i)\bMaxillofacial\s?Surgion\b",
    r"(?i)\bMaxillofacial\s?Suergeon\b",
    r"(?i)\bMaxillofacial\s?Srurgeon\b",
    r"(?i)\bMaxillofacial\s?Surrgeon\b",
    # Case Variations
    r"(?i)\bmaxillofacial surgeon\b",
    r"(?i)\bMaxillofacial surgeon\b",
    r"(?i)\bmaxillofacial Surgeon\b",
    r"(?i)\bMAXILLOFACIAL SURGEON\b",
    r"(?i)\bMaxillofaCial Surgeon\b",

    # Spanish Variants
    r"(?i)\bCirujano\s?Maxilofacial\b",
    r"(?i)\bEspecialista\s?Maxilofacial\b",
    r"(?i)\bMédico\s?Cirujano\s?Maxilofacial\b",
    r"(?i)\bDoctor\s?en\s?Cirugía\s?Maxilofacial\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bCraniofacial\s?Surgeon\b",
    r"(?i)\bMaxillofacial Surgery\b",
]

# Exact matches that should be updated
maxillofacial_exact_matches = {
    "Maxillofacial Surgeon",
    "Maxillofacial Surg",
    "MaxFac Surgeon",
    "Maxilofacial Surgeon",
    "Maxillofascial Surgeon",
    "Maxillofacil Surgeon",
    "Maxillofascial Surgon",
    "Maxillofascial Surgin",
    "Maxillofacial Surjeon",
    "Maxillofacial Surgan",
    "Maxillofacial Surgion",
    "Maxillofacial Suergeon",
    "Maxillofacial Srurgeon",
    "Maxillofacial Surrgeon",
    "Cirujano Maxilofacial",
    "Especialista Maxilofacial",
    "Médico Cirujano Maxilofacial",
    "Doctor en Cirugía Maxilofacial",
    "Craniofacial Surgeon",
    'Maxillofacial',
    'Max Fax',
}

# Define patterns (these should NOT be changed)
maxillofacial_exclusions = r'\b(?:Oral)\b'

# Create a mask for Maxillofacial Surgeon
mask_maxillofacial = df['speciality'].str.contains('|'.join(maxillofacial_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(maxillofacial_exact_matches)
mask_maxillofacial_exclusions = df['speciality'].str.contains(maxillofacial_exclusions, case=False, na=False, regex=True)

# Final mask: Select Maxillofacial Surgeon
mask_maxillofacial_final = mask_maxillofacial & ~mask_maxillofacial_exclusions

# Store the original values that will be replaced
original_maxillofacial_values = df.loc[mask_maxillofacial_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_maxillofacial_final, 'speciality'] = 'Maxillofacial Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Maxillofacial Surgeon", 'green'))
print(df.loc[mask_maxillofacial_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_maxillofacial_values = df.loc[mask_maxillofacial_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Maxillofacial Surgeon", "cyan"))
for original_maxillofacial_value in original_maxillofacial_values:
    print(f"✅ {original_maxillofacial_value} → Maxillofacial Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Maxillofacial Surgeon:", 'red'))
print(grouped_maxillofacial_values)

# Print summary
matched_count_maxillofacial = mask_maxillofacial_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Maxillofacial Surgeon: "
        f"{matched_count_maxillofacial}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Radiologist related titles

radiologist_variants = [
    # Standard Titles & Variants
    r"(?i)\bRadiologist\b",
    r"(?i)\bMedical Radiologist\b",
    r"(?i)\bRadiology Specialist\b",
    r"(?i)\bDiagnostic Radiologist\b",
    r"(?i)\bRadiology Consultant\b",
    r"(?i)\bInterventional Radiologist\b",
    r"(?i)\bNeuro Radiologist\b",
    r"(?i)\bSr  Radiographer\b",
    r"(?i)\bRadiology\b",
    r"(?i)\bUltrasound\b",

    # Misspellings & Typographical Errors
    r"(?i)\bRadioligist\b",
    r"(?i)\bRadialogist\b",
    r"(?i)\bRaadiologist\b",
    r"(?i)\bRaadiologyst\b",
    r"(?i)\bRadilogist\b",
    r"(?i)\bRaddiologist\b",
    r"(?i)\bRaodiologist\b",
    r"(?i)\bRadiolgist\b",

    # Case Variations
    r"(?i)\bRADIOLOGIST\b",
    r"(?i)\bradiologist\b",
    r"(?i)\bRaDiOlOgIsT\b",
    r"(?i)\bRADIOLIGIST\b",

    # Spanish Variants
    r"(?i)\bRadiólogo\b",
    r"(?i)\bEspecialista en Radiología\b",
    r"(?i)\bRadiólogo Clínico\b",
    r"(?i)\bRadiólogo de Diagnóstico\b",
    r"(?i)\bRadiólogo Intervencionista\b",
    r"(?i)\bRadiólogo Neurobiólogo\b",
    r"(?i)\bRadiólogo General\b",
    r"(?i)\bRadiólogo Oncológico\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bRadiologist en diagnóstico\b",
    r"(?i)\bRadiologist Intervencionista\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bDiagnostic Imaging Specialist\b",
    r"(?i)\bRadiology Technician\b",
    r"(?i)\bImaging Specialist\b",
    r"(?i)\bX-ray Specialist\b",
    r"(?i)\bCT Scan Specialist\b",
    r"(?i)\bMRI Specialist\b",
    r"(?i)\bInterventional Imaging Specialist\b",
]

# Exact matches that should be updated
radiologist_exact_matches = {
    "Radiologist",
    "Medical Radiologist",
    "Radiology Specialist",
    "Diagnostic Radiologist",
    "Radiology Consultant",
    "Interventional Radiologist",
    "Neuro Radiologist",
    "Radioligist",
    "Radialogist",
    "Raadiologist",
    "Raadiologyst",
    "Radilogist",
    "Raddiologist",
    "Raodiologist",
    "Radiolgist",
    "Radiólogo",
    "Especialista en Radiología",
    "Radiólogo Clínico",
    "Radiólogo de Diagnóstico",
    "Radiólogo Intervencionista",
    "Radiólogo Neurobiólogo",
    "Radiólogo General",
    "Radiólogo Oncológico",
    "Radiologist en diagnóstico",
    "Radiologist Intervencionista",
    "Diagnostic Imaging Specialist",
    "Radiology Technician",
    "Imaging Specialist",
    "X-ray Specialist",
    "CT Scan Specialist",
    "MRI Specialist",
    "Interventional Imaging Specialist",
    'RadiographerAesthetics',
}

# # Define patterns (these should NOT be changed)
# radiologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

radiologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Radiologist
mask_radiologist = df['speciality'].str.contains('|'.join(radiologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(radiologist_exact_matches)

# mask_radiologist_exclusions = df['speciality'].str.contains(radiologist_exclusions, case=False, na=False, regex=True)
mask_radiologist_exclusions = df['speciality'].isin(radiologist_exclusions)

# Final mask: Select Radiologist
mask_radiologist_final = mask_radiologist & ~mask_radiologist_exclusions

# Store the original values that will be replaced
original_radiologist_values = df.loc[mask_radiologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_radiologist_final, 'speciality'] = 'Radiologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Radiologist", 'green'))
print(df.loc[mask_radiologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_radiologist_values = df.loc[mask_radiologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Radiologist", "cyan"))
for original_radiologist_value in original_radiologist_values:
    print(f"✅ {original_radiologist_value} → Radiologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Radiologist:", 'red'))
print(grouped_radiologist_values)

# Print summary
matched_count_radiologist = mask_radiologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Radiologist: "
        f"{matched_count_radiologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Esthetician Cosmetician related titles

esthetician_variants = [
    r"(?i)\besthetician\b",
    r"(?i)\bcosmetician\b",
    r"(?i)\bestheticien\b",
    r"(?i)\bbeauty\s?therapist\b",
    r"(?i)\bcosmetic\s?esthetician\b",
    r"(?i)\blicensed\s?esthetician\b",
    r"(?i)\bcertified\s?esthetician\b",
    r"(?i)\bprofessional\s?esthetician\b",
    r"(?i)\bskin\s?care\s?specialist\b",
    r"(?i)\bcosmetic\s?specialist\b",
    r"(?i)\bskin\s?specialist\b",
    r"(?i)\bfacial\s?specialist\b",
    r"(?i)\bfacial\s?therapist\b",
    r"(?i)\bbeauty\s?specialist\b",
    r"(?i)\bbeauty\s?expert\b",
    r"(?i)\besthetician\s?MD\b",
    r"(?i)\bSkin Care\b",
    r"(?i)\bAesthetic Therapist\b",
    r"(?i)\bEstheticianMassage Therapist\b",
    r"(?i)\bDental Therapist\b",
    r"(?i)\bEsthetics\b",
    r"(?i)\bOther Cosmetic Beauty Specialty\b",
    r"(?i)\bOccupational Therapist\b",
    r"(?i)\bHair Removal\b",
    r"(?i)\bCosmetique\b",
    r"(?i)\bTherapist\b",
    r"(?i)\bBrows\b",
    r"(?i)\bCosmetologa Asesora\b",
    r"(?i)Aethetician",
    r"(?i)Aesthetician",
    r"(?i)Esthetician",
    r"(?i)Maquillista",
    r"(?i)\bKometyka\b",
    r"(?i)\bCertified Advanced EsthetcianAspiring Fnp\b",
    r"(?i)\bManicure Pedicure\b",
    r"(?i)\bEsthetic Beauty\b",
    r"(?i)\bSemi Permanent Makeup\b",
    r"(?i)\bSkintherapist & Podiatrist\b",
    r"(?i)\bCosmetic & Personal Care\b",
    r"(?i)\bFacialistBeautician\b",
    r"(?i)\bLash Master\b",
    r"(?i)\bNursBeautician\b",
    r"(?i)\bAltomaquiagem\b",
    r"(?i)\bPdo Threads\b",
    r"(?i)\bBeauticianPress\b",
    r"(?i)\bSkintherapist\b",
    r"(?i)\bHairSkin\b",
    r"(?i)\bAesthetic Laser Specialist\b",
    r"(?i)\bSkin & Laser Specialist\b",
    r"(?i)\bLazer & Skin Care Specialist\b",
    r"(?i)\bNurseSkin\b",
   r"(?i)\bParamedical Dermal\b",
   r"(?i)\bLaser Specialist\b",
   r"(?i)\bAesthetican\b",

    # Spanish variants
    r"(?i)\besteticista\b",  # Spanish form (esthetician)
    r"(?i)\besteticistas\b",  # Spanish plural form (esthetician)
    r"(?i)\bterapeuta\s?de\s?belleza\b",  # Spanish form (beauty therapist)
    r"(?i)\bestetista\s?profesional\b",  # Spanish form (professional esthetician)
    r"(?i)\bespecialista\s?en\s?cuidado\s?de\s?la\s?piel\b",  # Spanish form (skin care specialist)
    r"(?i)\besteticista\s?certificado\b",  # Spanish form (certified esthetician)

    # Other possible variations
    r"(?i)\bdoctor\s?in\s?esthetician\b",
    r"(?i)\bskin\s?care\s?doctor\b",
    r"(?i)\besthetician\s?expert\b",
    r"(?i)\bAesthetician\b",
    r"(?i)Aesthetician",
    r"(?i)\bAesthetician\b",
]

# Exact matches that should be updated
esthetician_exact_matches = {
    "Esthetician Cosmetician",
    "Certified Esthetician",
    "Beauty Therapist",
    "Skin Care Specialist",
    "Cosmetology Expert",
    "Facial Specialist",
    "Skincare",
    "Cosmetics",
    'Esthetics',
    'Esteticista',
    'Estheticienne',
    'Cosmetic Coordinator',
    'Hydro Facial',
    'Kosmetolog Massazhist',
    'Facial Massage',
    'Freelance Makeup Artist',
    'Internationally Certified Permananet Makeup Artist',
    'Esterica',
    'Waxing',
    'Micropigmentation',
    'Beauty Aesthetic',
    'Aestician',
    'Aesthetian',
    'Cosmetisc',
    'Aesthetian',
    'Facials',
    'Cosmetic NurseTrainer',
    'Aesthetcian',
    'Doctor Aestetician',
    'Facial consultant',
    'Cosmetic Lead',
}

# Define patterns (these should NOT be changed)
esthetician_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Cirujano General Medico Esteticista',
    'Esthetician Student',
    'Student Esthetician',
    'Aesthetician Student Nurse',
    'Medico CirujanoMedico Esteticista',
    'Skin Care Brand'
}

# Create a mask for Esthetician Cosmetician
mask_esthetician = df['speciality'].str.contains('|'.join(esthetician_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(esthetician_exact_matches)
mask_esthetician_exclusions = df['speciality'].isin(esthetician_exclusions)

# Final mask: Select Esthetician Cosmetician
mask_esthetician_final = mask_esthetician & ~mask_esthetician_exclusions

# Store the original values that will be replaced
original_esthetician_values = df.loc[mask_esthetician_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_esthetician_final, 'speciality'] = 'Esthetician Cosmetician'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Esthetician Cosmetician", 'green'))
print(df.loc[mask_esthetician_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_esthetician_values = df.loc[mask_esthetician_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Esthetician Cosmetician", "cyan"))
for original_esthetician_value in original_esthetician_values:
    print(f"✅ {original_esthetician_value} → Esthetician Cosmetician")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Esthetician Cosmetician:", 'red'))
print(grouped_esthetician_values)

# Print summary
matched_count_esthetician = mask_esthetician_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Esthetician Cosmetician: "
        f"{matched_count_esthetician}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Neurophysiologist related titles

neurophysiologist_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bNeurophysiologist\b",
    r"(?i)\bNeuro\s?Physiologist\b",
    r"(?i)\bNeuro\s?Physio\b",
    r"(?i)\bNeuro\s?Physiology\s?Specialist\b",
    r"(?i)\bNeurological\s?Physiologist\b",
    r"(?i)\bNeuro\s?Physiology\s?Doctor\b",
    r"(?i)\bConsultant\s?Neurophysiologist\b",
    r"(?i)\bSenior\s?Neurophysiologist\b",

    # Misspellings & Typographical Errors
    r"(?i)\bNeurophisiologist\b",
    r"(?i)\bNeurofysiologist\b",
    r"(?i)\bNeuropysiologist\b",
    r"(?i)\bNeurophysilogist\b",
    r"(?i)\bNeurophysiologst\b",
    r"(?i)\bNeurophysiolgist\b",
    r"(?i)\bNeurophysioloigst\b",
    r"(?i)\bNeuropsysiologist\b",
    r"(?i)\bNeurphysiologist\b",
    r"(?i)\bNeurophysiologits\b",
    r"(?i)\bNeurophysiolosgist\b",

    # Case Variations
    r"(?i)\bneurophysiologist\b",
    r"(?i)\bNeuroPhysiologist\b",
    r"(?i)\bNEUROPHYSIOLOGIST\b",
    r"(?i)\bNeurophysiOLogist\b",

    # Spanish Variants
    r"(?i)\bNeurofisiólogo\b",
    r"(?i)\bMédico\s?Neurofisiólogo\b",
    r"(?i)\bEspecialista\s?en\s?Neurofisiología\b",
    r"(?i)\bDoctor\s?en\s?Neurofisiología\b",
    r"(?i)\bConsultor\s?Neurofisiólogo\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bNeurodiagnostic\s?Physiologist\b",
    r"(?i)\bNeuro\s?Electrophysiologist\b",
    r"(?i)\bNeuro\s?Electrophysiology\s?Doctor\b",
    r"(?i)\bNeuroscience\s?Physiologist\b",
    r"(?i)\bClinical\s?Neurophysiologist\b",
    r"(?i)\bNeurophysiology\s?Expert\b",
]

# Exact matches that should be updated
neurophysiologist_exact_matches = {
    "Neurophysiologist",
    "Neuro Physiologist",
    "Neuro Physio",
    "Neuro Physiology Specialist",
    "Neurological Physiologist",
    "Neuro Physiology Doctor",
    "Consultant Neurophysiologist",
    "Senior Neurophysiologist",
    "Neurophisiologist",
    "Neurofysiologist",
    "Neuropysiologist",
    "Neurophysilogist",
    "Neurophysiologst",
    "Neurophysiolgist",
    "Neurophysioloigst",
    "Neuropsysiologist",
    "Neurphysiologist",
    "Neurophysiologits",
    "Neurophysiolosgist",
    "Neurofisiólogo",
    "Médico Neurofisiólogo",
    "Especialista en Neurofisiología",
    "Doctor en Neurofisiología",
    "Consultor Neurofisiólogo",
    "Neurodiagnostic Physiologist",
    "Neuro Electrophysiologist",
    "Neuro Electrophysiology Doctor",
    "Neuroscience Physiologist",
    "Clinical Neurophysiologist",
    "Neurophysiology Expert",
}

# # Define patterns (these should NOT be changed)
# neurophysiologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

neurophysiologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Neurophysiologist
mask_neurophysiologist = df['speciality'].str.contains('|'.join(neurophysiologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(neurophysiologist_exact_matches)

# mask_neurophysiologist_exclusions = df['speciality'].str.contains(neurophysiologist_exclusions, case=False, na=False, regex=True)
mask_neurophysiologist_exclusions = df['speciality'].isin(neurophysiologist_exclusions)

# Final mask: Select Neurophysiologist
mask_neurophysiologist_final = mask_neurophysiologist & ~mask_neurophysiologist_exclusions

# Store the original values that will be replaced
original_neurophysiologist_values = df.loc[mask_neurophysiologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_neurophysiologist_final, 'speciality'] = 'Neurophysiologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Neurophysiologist", 'green'))
print(df.loc[mask_neurophysiologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_neurophysiologist_values = df.loc[mask_neurophysiologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Neurophysiologist", "cyan"))
for original_neurophysiologist_value in original_neurophysiologist_values:
    print(f"✅ {original_neurophysiologist_value} → Neurophysiologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Neurophysiologist:", 'red'))
print(grouped_neurophysiologist_values)

# Print summary
matched_count_neurophysiologist = mask_neurophysiologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Neurophysiologist: "
        f"{matched_count_neurophysiologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Company Medical Staff related titles

company_medical_staff_variants = [
    r"(?i)\bcompany\s?medical\s?staff\b",
    r"(?i)\bmedical\s?staff\s?of\s?company\b",
    r"(?i)\bcorporate\s?medical\s?staff\b",
    r"(?i)\bcompany\s?healthcare\s?team\b",
    r"(?i)\borganization\s?medical\s?staff\b",
    r"(?i)\bmedical\s?team\s?of\s?company\b",
    r"(?i)\bcompany\s?medcal\s?staff\b",
    r"(?i)\bcompnay\s?medical\s?staff\b",
    r"(?i)\bcompany\s?mdeical\s?staff\b",
    r"(?i)\bcompany\s?mediccal\s?staff\b",
    r"(?i)\bcompany\s?medikal\s?staff\b",
    r"(?i)\bpersonal\s?médico\s?de\s?empresa\b",
    r"(?i)\bstaff\s?médico\s?de\s?compañía\b",
    r"(?i)\bequipo\s?médico\s?de\s?empresa\b",
    r"(?i)\bempleados\s?médicos\s?corporativos\b",
    r"(?i)\bcompany\s?physician\s?team\b",
    r"(?i)\bmedical\s?professionals\s?of\s?company\b",
    r"(?i)\bcorporate\s?health\s?staff\b",
    r"(?i)\bCompanyS Medical Staff\b",
    r"(?i)\bMedical\s?Team\b",
]

# Exact matches that should be updated
company_medical_staff_exact_matches = {
    'Company Medical Staff',
    'CompanyS Medical Staff',
    'Corporate Medical Staff',
    'Medical Team of Company',
    'Organization Medical Staff',
    'Company Healthcare Team',
    'Company Physician Team',
    'Medical Professionals of Company',
    'Corporate Health Staff',
    'Medical Staff',
    'medical staff',
    'med staff',
    'medicl staf',
    'Medical staff',
    'medical staff',
    'Medicalstaff',
    'MedicalStaff',
    'Medial Staff',
    'Medicla Staff',
    'MEDICAL STAFF',
    'medical staff',
    'Equipo Médico',
    'Medical Staff',
    'Medical Team',
    'Medial Team',
    'medical TEAM',
    'Physician Recruiter',
    'Senior Physician Recruiter',
    'Physician Recruitment',
    'Director Of Physician Recruitment',
    'Manager Physician Recruitment',
    'Physician Relations Manager',
    'Physician Relations Director',
    'Physician Recruitment Manager',
    'Director Physician Recruitment',
    'Assistant Vice President & Revenue Cycle Physician',
    'Associate Physician Recruiter',
    'Clinician & Physician Sourcer',
    'Coordinator - Physician Recruitment',
    'Corporate Director Physician Recruitment',
    'Dermatology Relations Professional',
    'Director Human Resources & Ambulatory & Services Physician',
    'Director Human Resources & Recruitment Physician',
    'Director Of Physician Relations',
    'Director Of Physician Services Ii',
    'Director Patient Services Programs Dermatology Psoriatic Disease Us',
    'Director Physician & Provider Recruitment',
    'Director Physician Recruitment - Connecticut & Supported Rhode Island Market',
    'Director Physician Relations',
    'Director Physician Relationship Management Technology',
    'Director Physician Talent',
    'Director Revenue Cycle & Premier Network Physician',
    'Director System & Recruitment Physician',
    'Cdi Physician Advisor',
    'Physician Liaison',
    'Clinician- Colorado Physician Health Program',
    'Division Manager Licensing For The Mn Board Of Cosmetology',
    'Ems& Cosmetology Licensing Aide Professional',
    'Executive Assistant To Cao & Physician Liaison',
    'Executive Assistant Dermatology',
    'Executive Community Physician Leader',
    'Executive Vp Chief Physician Executive & Chief Clinical Officer',
    'Field Director- Immunology & Dermatology',
    'Heor Strategy Dermatology Launches & Pipeline Lead',
    'Heritage Network Physicians',
    'Integrated Physician Omni Healthcare',
    'Internal Physician Relations Manager',
    'National Field Director Dermatology',
    'Nephrology Physician Recruiter',
    'Obgyn Physician Recruiter',
    'Pediatric Physician Recruiter',
    'Physician & Advanced Practice Provider Recruiter',
    'Physician & Apc Recruiter',
    'Physician & App Recruiter',
    'Physician & Faculty Recruiter',
    'Physician & Professional Clinic Talent Acquisition Specialist',
    'Physician & Provider Recruiter',
    'Physician & Provider Relations Manager',
    'Physician & Provider Relationship Manager',
    'Physician Access Coordinator',
    'Physician Access Coordinator Referring Physician Office',
    'Physician App & Leadership Recruiter',
    'Physician Outreach Coordinator',
    'Physician Outreach Specialist',
    'Physician Partnership Network Manager',
    'Physician Recruiter & Contracts Coordinator',
    'Physician Recruiter - Otolaryngology Ent & Internal Medicine Consultant',
    'Physician Recruiter Specialist',
    'Physician Recruiter--Emergency Medicine',
    'Physician Recruitment Assistant',
    'Physician Recruitment Specialist Senior',
    'Physician Relations Associate',
    'Physician Relations Coordinator',
    'Physician Resilience Medical Director',
    'Physician Resource Officer',
    'Physician Resources',
    'Physician Resources Specialist',
    'Physician Review Coordinator',
    'Physician Scheduler',
    'Physician Scheduler Provider Services Southeast Group',
    'Physician Sourcer',
    'Physician Support Specialist',
    'Regional Physician Services Manager',
    'Revenue Cycle Physicians Pfs',
    'Scheduler Dermatology',
    'Senior Engineer Medical Device Imaging Systems For Dermatology',
    'Senior Physician & Apc Recruiter',
    'Senior Physician Recruiter Remote',
    'Senior Physician Recruiter- Emergency Medicine - Nebraska Iowa Arkansas & Kentucky',
    'Specialist-Physician Relations',
    'Teleradiologist Physician Contractor',
    'Trauma & General Surgery App Supervisor',
    'Veterinary Technician- Dermatology',
    'Vice President Of Ambulatory & Physician Services',
    'Vice President Penn Highlands Physician Network',
    'Vice President Physician Acquisition',
    'Vice President Physician Development',
    'Vice President Physician Partnerships',
    'Vice President Physician Services',
    'Vice President- Physician Strategy Growth & Development',
    'Endo Aesthetics',
    'PowerAestheticGROUP',
    'Allergan Practice Consultant Facial Aesthetics',
    'Director Provider',
}

# Define patterns (these should NOT be changed)
company_medical_staff_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident'
}

# Create a mask for Company Medical Staff
mask_company_medical_staff = df['speciality'].str.contains('|'.join(company_medical_staff_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(company_medical_staff_exact_matches)
mask_company_medical_staff_exclusions = df['speciality'].isin(company_medical_staff_exclusions)

# Final mask: Select Company Medical Staff
mask_company_medical_staff_final = mask_company_medical_staff & ~mask_company_medical_staff_exclusions

# Store the original values that will be replaced
original_company_medical_staff_values = df.loc[mask_company_medical_staff_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_company_medical_staff_final, 'speciality'] = 'Company Medical Staff'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Company Medical Staff", 'green'))
print(df.loc[mask_company_medical_staff_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_company_medical_staff_values = df.loc[mask_company_medical_staff_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Company Medical Staff", "cyan"))
for original_company_medical_staff_value in original_company_medical_staff_values:
    print(f"✅ {original_company_medical_staff_value} → Company Medical Staff")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Company Medical Staff:", 'red'))
print(grouped_company_medical_staff_values)

# Print summary
matched_count_company_medical_staff = mask_company_medical_staff_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Company Medical Staff: "
        f"{matched_count_company_medical_staff}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Owner related titles

owner_variants = [
    # Standard Titles & Variants
    r"(?i)\bOwner\b",
    r"(?i)\bBusiness\s?Owner\b",
    r"(?i)\bCompany\s?Owner\b",
    r"(?i)\bFounder\b",
    r"(?i)\bCo\s?-?\s?Owner\b",
    r"(?i)\bEntrepreneur\b",
    r"(?i)\bSole\s?Proprietor\b",
    r"(?i)\bManaging\s?Owner\b",
    r"(?i)\bPrincipal\s?Owner\b",
    r"(?i)\bOwner\s?and\s?CEO\b",
    r"(?i)\bOwner\s?and\s?Founder\b",
    r"(?i)\bOwner\s?Operator\b",
    r"(?i)\bSelf\s?-?\s?Employed\b",
    r"(?i)\bIndependent\s?Business\s?Owner\b",
    r"(?i)\bManaging Partner\b",
    r"(?i)\bProprietor\b",
    r"(?i)\bPartners\b",
    r"(?i)\bMedico Proprietario\b",
    r"(?i)Proprietario",
    r"(?i)\bOwnerGeneral Manager\b",
    r"(?i)\bEntrepreneure Independante\b",
    r"(?i)\bOwners\b",
    r"(?i)\bBusiness Woman\b",
    r"(?i)\bOwnerBarbara JS Chocolates\b",
    r"(?i)\bPropietariaEnfermera Cosmetologa\b",
    r"(?i)\bOwnerbuyer\b",
    r"(?i)\bOwnere\b",
    r"(?i)\bOwnerCrnp\b",
    r"(?i)\bInjectorOwner\b",
    r"(?i)\bDirectorOwner\b",
    r"(?i)\bOwnerPhysician Associate\b",

    # Misspellings & Typographical Errors
    r"(?i)\bOner\b",
    r"(?i)\bOnwer\b",
    r"(?i)\bOwneer\b",
    r"(?i)\bOwnr\b",
    r"(?i)\bOwwner\b",
    r"(?i)\bOwnwer\b",

    # Case Variations
    r"(?i)\bowner\b",
    r"(?i)\bOwNeR\b",
    r"(?i)\bOWNER\b",
    r"(?i)\bOwNer\b",

    # Spanish Variants
    r"(?i)\bPropietario\b",
    r"(?i)\bDueño\b",
    r"(?i)\bTitular\b",
    r"(?i)\bFundador\b",
    r"(?i)\bEmprendedor\b",
    r"(?i)\bAutónomo\b",
    r"(?i)\bGerente\s?Propietario\b",
    r"(?i)\bDueño\s?de\s?Negocio\b",
    r"(?i)\bPropietario\s?de\s?Empresa\b",

    # Other Possible Variations
    r"(?i)\bBusiness\s?Founder\b",
    r"(?i)\bBusiness\s?Partner\b",
    r"(?i)\bBusiness\s?Owner\s?Operator\b",
    r"(?i)\bCompany\s?Director\b",
    r"(?i)\bEnterprise\s?Owner\b",
    r"(?i)\bStart-up\s?Founder\b",
    r"(?i)\bAesthetic Provider\b",
    r"(?i)\bBoss\b",
]

# Exact matches that should be updated
owner_exact_matches = {
    "Owner",
    "Business Owner",
    "Company Owner",
    "Founder",
    "Co-Owner",
    "Entrepreneur",
    "Sole Proprietor",
    "Managing Owner",
    "Principal Owner",
    "Owner and CEO",
    "Owner and Founder",
    "Owner Operator",
    "Self-Employed",
    "Independent Business Owner",
    "Oner",
    "Onwer",
    "Owneer",
    "Ownr",
    "Owwner",
    "Ownwer",
    "Propietario",
    "Dueño",
    "Titular",
    "Fundador",
    "Emprendedor",
    "Autónomo",
    "Gerente Propietario",
    "Dueño de Negocio",
    "Propietario de Empresa",
    "Business Founder",
    "Business Partner",
    "Business Owner Operator",
    "Company Director",
    "Enterprise Owner",
    "Start-up Founder",
    "Partner",
    'OwnerDirector',
    'CeoOwner',
    'OwnerCeoPresidentManaging Director',
    'OwnerExecutive Consultant',
    'OwnerLead Injector',
    'OwnerManaging Director',
    'OwnerNurse Injector',
    'Ownerhospital Director',
    'OwnerFounder',
    'Senior Partner',
    'Partner Innovation&Development',
    'PartnerOwner',
    'OwnerPresidentCeo',
    'SocioPropietarioEmpresario',
    'Bisnesman',
    'Inventor',
    'PodiatristOwner',
    'MDOWNER',
    'Ownerpractitioner',
    'RNOwner',
    'RNowner',
    'Nurse PractitionerOwner',
    'ARNPOwner',
    'SOCIA PROPRIETARIA',
}

# # Define patterns (these should NOT be changed)
# owner_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

owner_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Physician & Owner',
    'Oral & Facial Surgeon & & Owner',
    'Physician & Founder',
    'Plastic Surgeon Owner',
    'Physician Co-Owner',
    'Owner Physician',
    'Owner & Physician',
    'Periodontist & Dental Implant Surgeon & Owner',
    'Physician & Founder Interventional Cardiology',
    'Family Practice Physician Owner',
    'Physician-Owner',
    'Owner Plastic Surgeon',
    'Physician Founder',
    'Physician Medical Director & Owner',
    'Plastic Surgeon & Owner',
    'Plastic Surgeon & Co-Founder',
    'Physician Owner',
    'Physician & Co-Founder',
}

# Create a mask for Owner
mask_owner = df['speciality'].str.contains('|'.join(owner_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(owner_exact_matches)

# mask_owner_exclusions = df['speciality'].str.contains(owner_exclusions, case=False, na=False, regex=True)
mask_owner_exclusions = df['speciality'].isin(owner_exclusions)

# Final mask: Select Owner
mask_owner_final = mask_owner & ~mask_owner_exclusions

# Store the original values that will be replaced
original_owner_values = df.loc[mask_owner_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_owner_final, 'speciality'] = 'Owner'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Owner", 'green'))
print(df.loc[mask_owner_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_owner_values = df.loc[mask_owner_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Owner", "cyan"))
for original_owner_value in original_owner_values:
    print(f"✅ {original_owner_value} → Owner")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Owner:", 'red'))
print(grouped_owner_values)

# Print summary
matched_count_owner = mask_owner_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Owner: "
        f"{matched_count_owner}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Clinic Manager related titles

clinic_manager_variants = [
    r"(?i)\bClinic\s?Manager\b",
    r"(?i)\bClinic\s?Administrator\b",
    r"(?i)\bHealthcare\s?Manager\b",
    r"(?i)\bMedical\s?Office\s?Manager\b",
    r"(?i)\bClinic\s?Supervisor\b",
    r"(?i)\bHealthcare\s?Administrator\b",
    r"(?i)\bNurse Manager\b",
    r"(?i)\bAestheticianClinic Manager\b",
    r"(?i)\bCentro Medico Azuaje\b",
    r"(?i)\bMedica Clinica Medica\b",
    r"(?i)\bTransportation Before & After Aesthetic Chirurgical Intervention\b",
    r"(?i)\bChief Of Staff\b",
    r"(?i)\bClinical Receptionist\b",
    r"(?i)\bOffice Mgr\b",
    r"(?i)\bClinical Support Services Manager\b",
    r"(?i)\bClinica Geral\b",
    r"(?i)\bClinico Geral\b",
    r"(?i)\bRnbn Clinic Director Plastic Surgery Centre\b",
    r"(?i)\bClinic Manager\b",
    r"(?i)\bClinic Administrator\b",
    r"(?i)\bClinicHospital\b",
    r"(?i)\bDental Clinic\b",
    r"(?i)\bAestetic Clinic Partner\b",
    r"(?i)\bRejenerative Clinic\b",
    r"(?i)\bOffice Manager\b",
    r"(?i)\bMedica Clinico Geral\b",
    r"(?i)\bClinical Receptionist\b",
    r"(?i)\bCeo Elite Helse Clinic\b",
    r"(?i)\bChief Of Staff\b",
    r"(?i)\bClinic CoordinatorBesuty Therapist\b",
    r"(?i)\bThe Pretty Young Clinic Seoul Korea\b",
    r"(?i)\bOffice Mgr\b",
    r"(?i)\bClinic Assistant\b",
    r"(?i)\bClinical Support Services Manager\b",
    r"(?i)\bClinica Geral\b",
    r"(?i)\bClinic Nurse\b",
    r"(?i)\bAesthetic Clinic Director\b",
    r"(?i)\bClinico Geral\b",
    r"(?i)\bClinic ManagerAnti-Aging Spacialist\b",
    r"(?i)\bAesthetic & Cosmetic Clinic\b",
    r"(?i)\bCentro Medico Azuaje\b",
    r"(?i)\bCeo Full Face Clinic\b",
    r"(?i)\bClinic Management\b",
    r"(?i)\bTransportation Before & After Aesthetic Chirurgical Intervention\b",
    r"(?i)\bClinic DirectorPlastic SurgeryRnbn\b",
    r"(?i)\bMedical Clinic Aesthetic Practice\b",
    r"(?i)\bRnbn Clinic Director Plastic Surgery Centre\b",
    r"(?i)\bClinic Management Ownership & Administration\b",
    r"(?i)\bDirector Cutaneous Imaging Clinic\b",
    r"(?i)\bCeo Of A Dermaesthetic Clinic\b",
    r"(?i)\bPain Rehabilitation Clinic\b",
    r"(?i)\bMedica Clinica Medica\b",
    r"(?i)\bNurse Manager\b",
    r"(?i)\bCeo Of Medical Clinic\b",
    r"(?i)\bClinic Director\b",
    r"(?i)\bHappy Aging Clinic Ceo\b",
    r"(?i)\bAesthetician & Clinic Assistant\b",
    r"(?i)\bCeo Of Aesthetic Clinic\b",
    r"(?i)\bClinical Nurse Manager\b",
    r"(?i)\bBeauty Clinic Ceo\b",
    r"(?i)\bDirector Of Ginza Tarumi Clinic\b",
    r"(?i)\bClinical Nurse Manager Emergency Department\b",
    r"(?i)\bHead Of The Clinic\b",
    r"(?i)\bMedica Clinica Geral\b",
    r"(?i)\bStem Cell Clinic\b",
    r"(?i)\bNurse Manager Rn\b",
    r"(?i)\bMember - Board Of Trustees Chief Of Staff - Umh Hospitals\b",
    r"(?i)\bAestheticianClinic Manager\b",
    r"(?i)\bClinic Manager Laser & Cosmetic Treatments\b",
    r"(?i)\bAesthetic Clinic Manager\b",
    r"(?i)\bHead Of Clinic\b",
    r"(?i)\bClinical Nurse Manager Of Behavioral Health Outpatient Services\b",
    r"(?i)\bClinic Manager Esthetician Not Using Injectables\b",
    r"(?i)\bClinical Nurse Manager Nicu Uh Rainbow Babies & ChildrenS\b",
    r"(?i)\bClinic ManagerAesthetican\b",
    r"(?i)\bClinic Director Of Cares Clinic\b",
    r"(?i)\bWellness Clinic\b",
    r"(?i)\bCoo Of A Clinic For Plastic Surgery\b",
    r"(?i)\bClinical Operations\b",
    r"(?i)\bClinical Governance\b",
    r"(?i)\bManager For Dr  Aziz\b",
]

# Exact matches that should be updated
clinic_manager_exact_matches = {
    'Clinic Manager',
    'Clinic Administrator',
    'Healthcare Manager',
    'Medical Office Manager',
    'Clinic Supervisor',
    'Healthcare Administrator',
    'Clinic',

    # Case-related errors
    'clinic manager',
    'clinic administrator',
    'healthcare manager',
    'medical office manager',
    'medical practice manager',
    'clinic supervisor',
    'healthcare administrator',
    'CLINIC MANAGER',
    'CLINIC ADMINISTRATOR',
    'HEALTHCARE MANAGER',
    'MEDICAL OFFICE MANAGER',
    'CLINIC SUPERVISOR',
    'HEALTHCARE ADMINISTRATOR',

    # Common misspellings
    'Clinic Maneger',
    'Clinic Mangager',
    'Clinc Manager',
    'Clinc Maneger',
    'Clinic Mananger',
    'Medial Office Manager',
    'Medicl Office Manager',
    'Medical Office Manger',

    # Spanish-related exclusions
    'Gerente de Clínica',
    'Administrador de Clínica',
    'Gerente de Atención Médica',
    'Gerente de Oficina Médica',
    'Supervisor de Clínica',
    'Administrador de Atención Sanitaria',
    
    # value from data sources
    'Clinic/Hospital',
    'Office Manager',
    'ClinicHospital',
    'Booking Manager',
    'Clinical Manager',
    'Clinic Hospital',
    'Private Clinic Hospital',
    'Other Clinic Hospital',
    'Clinic Operations Director',
    'Clinical Administrator',
    'Lead Patient Coordinator',
    'Treatment Coordinator',
    'Front Desk- Advanced Dermatology',
    'Medical Biller Dermatology',
    'Director of clinic operations',
    'Aesthetics Coordinator',
    'Aesthetics Manager',
    'Aesthetic Manager',
    'Cosmetic Manager',
    'COSMETIC MANAGER',
    'Cosmetic manage',
    'ARC',
    'Adm A',
    'Aesthetic Experience Manager',
    'Aesthetic Supervisor',
    'CHEF DE CLINIQUE',
    'CMM',
    'Consultation Co-ordinator',
    'Cosmetic Supervisor',
    'Director of WOO',
    'Executive Patient Concierge',
}

# Define patterns for  & Resident & Professor (these should NOT be changed)
clinic_manager_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Clinic Manager
mask_clinic_manager = df['speciality'].str.contains('|'.join(clinic_manager_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(clinic_manager_exact_matches)
mask_clinic_manager_exclusions = df['speciality'].isin(clinic_manager_exclusions)

# Final mask: Select Clinic Manager
mask_clinic_manager_final = mask_clinic_manager & ~mask_clinic_manager_exclusions

# Store the original values that will be replaced
original_clinic_manager_values = df.loc[mask_clinic_manager_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_clinic_manager_final, 'speciality'] = 'Clinic Manager'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Clinic Manager", 'green'))
print(df.loc[mask_clinic_manager_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_clinic_manager_values = df.loc[mask_clinic_manager_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Clinic Manager", "cyan"))
for original_clinic_manager_value in original_clinic_manager_values:
    print(f"✅ {original_clinic_manager_value} → Clinic Manager")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Clinic Manager:", 'red'))
print(grouped_clinic_manager_values)

# Print summary
matched_count_clinic_manager = mask_clinic_manager_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Clinic Manager: "
        f"{matched_count_clinic_manager}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Research Scientist related titles

research_scientist_variants = [
    # Standard Titles & Variants
    r"(?i)\bResearch Scientist\b",
    r"(?i)\bScientific Researcher\b",
    r"(?i)\bScientist\b",
    r"(?i)\bPrincipal Investigator\b",
    r"(?i)\bLaboratory Scientist\b",
    r"(?i)\bScientific Researcher (Research Scientist)\b",
    r"(?i)\bResearch Associate\b",
    r"(?i)\bPostdoctoral Researcher\b",
    r"(?i)\bBiomedical Research Scientist\b",
    r"(?i)\bR&D\b",
    r"(?i)\bAnalyst\b",
    r"(?i)\bResearcher\b",
    r"(?i)\bRa\b",
    r"(?i)\bOrganism\b",
    r"(?i)\bPrecision Medicine\b",
    r"(?i)\bScientific Writer\b",
    r"(?i)\bEvidence Generation\b",
    r"(?i)\bDirecteur Scientifique\b",
    r"(?i)\bScientific Manager\b",
    r"(?i)\bChief Scientific Officer\b",
    r"(?i)\bInnovation Et Valorisation Scientifique\b",
    r"(?i)\bBioinformatics\b",
    r"(?i)\bScientifique\b",
    r"(?i)\bEnvironmental Health\b",

    # Misspellings & Typographical Errors
    r"(?i)\bReseach Scientist\b",
    r"(?i)\bResearch Scienist\b",
    r"(?i)\bReserch Scientist\b",
    r"(?i)\bResarch Scientist\b",
    r"(?i)\bReseach Sientist\b",

    # Case Variations
    r"(?i)\bRESEARCH SCIENTIST\b",
    r"(?i)\bResearch SCIENTIST\b",
    r"(?i)\bresearch scientist\b",
    r"(?i)\bRESEARCH scientist\b",

    # Spanish Variants
    r"(?i)\bCientífico Investigador\b",
    r"(?i)\bInvestigador Científico\b",
    r"(?i)\bCientífico de Investigación\b",
    r"(?i)\bInvestigador\b",
    r"(?i)\bInvestigador Postdoctoral\b",
    r"(?i)\bInvestigador Principal\b",
    r"(?i)\bCientífico Biomédico\b",
    r"(?i)\bCientífico de Laboratorio\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bResearch Científico\b",
    r"(?i)\bResearcher Científico\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bBiomedical Researcher\b",
    r"(?i)\bLaboratory Researcher\b",
    r"(?i)\bResearch Specialist\b",
    r"(?i)\bSenior Research Scientist\b",
    r"(?i)\bResearch Director\b",
    r"(?i)\bPrincipal Investigator (Research Scientist)\b",
    r"(?i)\bScientific Lead\b",
    r"(?i)\bClinical Research Scientist\b",
    r"(?i)\bResearch Coordinator\b",
    r"(?i)\bResearch\b",
    r"(?i)\bScoentist\b",
    r"(?i)\bVeterinary Science\b",
]

# Exact matches that should be updated
research_scientist_exact_matches = {
    "Research Scientist",
    "Scientific Researcher",
    "Scientist",
    "Principal Investigator",
    "Laboratory Scientist",
    "Scientific Researcher (Research Scientist)",
    "Research Associate",
    "Postdoctoral Researcher",
    "Biomedical Research Scientist",
    "Reseach Scientist",
    "Research Scienist",
    "Reserch Scientist",
    "Resarch Scientist",
    "Reseach Sientist",
    "Científico Investigador",
    "Investigador Científico",
    "Científico de Investigación",
    "Investigador",
    "Investigador Postdoctoral",
    "Investigador Principal",
    "Científico Biomédico",
    "Científico de Laboratorio",
    "Research Científico",
    "Researcher Científico",
    "Biomedical Researcher",
    "Laboratory Researcher",
    "Research Specialist",
    "Senior Research Scientist",
    "Research Director",
    "Principal Investigator (Research Scientist)",
    "Scientific Lead",
    "Clinical Research Scientist",
    "Research Coordinator",
    "Research",
    'Chief Science Officer',
    'Doctorat En Sciences De La Vie Et De La Sante - Specialisation Vieillissement Et Glycations',
    'Diretora De Pesquisa E Desenvolvimento',
    'Principal Medical Writer',
    'Exosome Specialist',
}

# # Define patterns (these should NOT be changed)
# research_scientist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

research_scientist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'General Surgery Research Resident',
    'Epic Resolute Hospital Billing & Physician Billing Senior Analyst',
}

# Create a mask for Research Scientist
mask_research_scientist = df['speciality'].str.contains('|'.join(research_scientist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(research_scientist_exact_matches)

# mask_research_scientist_exclusions = df['speciality'].str.contains(research_scientist_exclusions, case=False, na=False, regex=True)
mask_research_scientist_exclusions = df['speciality'].isin(research_scientist_exclusions)

# Final mask: Select Research Scientist
mask_research_scientist_final = mask_research_scientist & ~mask_research_scientist_exclusions

# Store the original values that will be replaced
original_research_scientist_values = df.loc[mask_research_scientist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_research_scientist_final, 'speciality'] = 'Research Scientist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Research Scientist", 'green'))
print(df.loc[mask_research_scientist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_research_scientist_values = df.loc[mask_research_scientist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Research Scientist", "cyan"))
for original_research_scientist_value in original_research_scientist_values:
    print(f"✅ {original_research_scientist_value} → Research Scientist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Research Scientist:", 'red'))
print(grouped_research_scientist_values)

# Print summary
matched_count_research_scientist = mask_research_scientist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Research Scientist: "
        f"{matched_count_research_scientist}",
        'red'))